function [d,ecount_L]=combfit_eval(FitParameters,ecount_L)
%Function to make al evaluation how far is multidistributional fit from intial distribution
%inputs:
%FitParameters	-  parameters of distributions - matrix with rows of Mean(1), Standard deviation (2), and amlitude(3)
%ecount_L	- Counter ofthis function evaluations

%Outputs:
%d	- evaluated difference betweel fit and initial curve
%ecount_L	- Counter ofthis function evaluations

global Hst Bins ScaleMode DistrNum DistrType MinBins MaxBins IntermPlotStep WeightMatrix FitStage MeanGuessStep SumHst StdGuess

FitParameters=reshape(FitParameters,round(length(FitParameters)/DistrNum),DistrNum);
%calculate fitted distribution
HstFit=zeros(size(Hst));	%Initialize fitted distribution
for i=1:DistrNum	%cycle through separate distributions to add them
	switch DistrType	%type of distributtions used for fitting
	case 'Normal distribution'
		switch FitStage	%Stage of fitting process
		case 'PosAmpl'
			FitParameters(1,i)=inf2range(MinBins-(MaxBins-MinBins)/2,MaxBins+(MaxBins-MinBins)/2,FitParameters(1,i));	%mean values
			%StdGuess=MeanGuessStep/4;	% Standard deviation values
			FitParameters(2,i)=inf2range(0,2*SumHst,FitParameters(2,i));	% amplitude values
			BorderProb=FitParameters(2,i)*normcdf(Bins,FitParameters(1,i),StdGuess(i));	%CDF probabilities on the borders of the bins
		case 'PosStdAmpl'
			FitParameters(1,i)=inf2range(MinBins-(MaxBins-MinBins)/2,MaxBins+(MaxBins-MinBins)/2,FitParameters(1,i));	%Mean values
			FitParameters(2,i)=inf2range(0,(MaxBins-MinBins),FitParameters(2,i));	% Standard deviation values
			FitParameters(3,i)=inf2range(0,2*SumHst,FitParameters(3,i));	% amplitude values
			BorderProb=FitParameters(3,i)*normcdf(Bins,FitParameters(1,i),FitParameters(2,i));	%CDF probabilities on the borders of the bins
		end
			
	end	%type of distributtions used for fitting
	Add=(BorderProb(2:end)-BorderProb(1:(end-1)));
% 	if ~isempty(find(isnan(Add)))%!!!
% 		disp('stop');
% 	end
	Add(isnan(Add))=0;
% 	if min(Add)<=0%!!!
% 		disp(Add);
% 	end
	HstFit=HstFit+Add;	%probabilities to fit into the bin
end	%cycle through separate distributions to add them

% if min(HstFit)<0%!!!
% 	disp(HstFit);
% end

switch ScaleMode	%Mode of scaling and weighting for difference calculation
case 'Linear'
	%Compute difference with original distribution
	d=sum((HstFit-Hst).^2)^0.5;
case 'Log'
	HstFit=log10([loghst(HstFit)]);
	%Compute difference with original distribution
	d=sum((HstFit-Hst).^2)^0.5;
case 'LogMaxWeighted'
	HstFit=log10([loghst(HstFit)]);
	%Compute difference with original distribution
	d=HstFit-Hst;
	d=d.*WeightMatrix;
	d=sum(d.^2)^0.5;
end		%Mode of scaling and weighting for difference calculation

ecount_L=ecount_L+1;	%Add one to function evaluations count



%!!!!!!!!!
if IntermPlotStep~=0	%If Add control plot of the fit curve
	if round(ecount_L/IntermPlotStep)==ecount_L/IntermPlotStep	%time to add a curve
		%*** Creation bins' bunradies for plotting
		for i=1:(length(Bins)-1)
			BinsTp(i)=(Bins(i)+Bins(i+1))/2;	%Assigning a bin boundaries mean as a plot bin value
		end
		switch ScaleMode	%Mode of scaling and weighting for difference calculation
		case 'Linear'	%Need logscale
			HstFitP=log10([loghst(HstFit)]);
			HstP=log10([loghst(Hst)]);
		otherwise	%Already log scale
			HstFitP=HstFit;
			HstP=Hst;
		end	%Use logarithmic scale for difference calculation
		
		if IntermPlotStep>0	%Add control plot of the fit curve
			hp=plot(BinsTp,HstFitP,'Color', [(1-IntermPlotStep/ecount_L),(1-2*abs(IntermPlotStep-ecount_L/2)/ecount_L),(IntermPlotStep/ecount_L)]);
		else	%Add the first control plot of the fit curve
			IntermPlotStep=-IntermPlotStep;
			figure;
			hp=plot(BinsTp,HstP,'Color','blue','LineWidth',2);
			hold on;
			hp=plot(BinsTp,HstFitP,'m');
		end	%Add control plot of the fit curve
	end	%time to add a curve
end	%If Add control plot of the fit curve
% 
%!!!!!!!!!





function	Out=inf2range(A,B,In)

%Inputs:
%A - lower boundary
%B - upper boundary
%In - value from 0 to Inf

%Outputs:
%Out - value in the range

Out=A+(B-A)*(1./(1+exp(-In)));

function	Out=halfinf2range(A,B,In)

%Inputs:
%A - lower boundary
%B - upper boundary
%In - value from 0 to Inf

%Outputs:
%Out - value in the range

Out=B+(A-B)*exp(-In);

