function [d,ecount_L]=multi2singlechnl_eval(FitParameters,ecount_L)
%Function to make al evaluation how far is multidistributional fit from intial distribution
%inputs:
%FitParameters	-  parameters of distributions - matrix with rows of Mean(1), Standard deviation (2), and amlitude(3)
%ecount_L	- Counter ofthis function evaluations

%Outputs:
%d	- evaluated difference betweel fit and initial curve
%ecount_L	- Counter ofthis function evaluations

global Hst Bins BinsMedians ScaleMode ChnlNum DistrType IntermPlotStep WeightMatrix VaryChnlProb VaryChnlCrnt...
	MultiChnlProb MultiChnlCrnt ChnlBinsMediansList ChnlBinsList ChnlBinsMedians ChnlBins ComparisonRange

%---------- Extract histogram and scaling coefficients from the fit parameters
ChnlHst=FitParameters(1:length(ChnlBinsMedians));
%Retreive an array of scaled total probabilities to see 1, 2, 3,.. n channel(s) (if necessary)
if VaryChnlProb==1	%vary (scale) <1> or not <0> the total probability to see 1, 2, 3,.. n channel(s).
	MultiChnlProb=FitParameters((length(ChnlHst)+1):(length(ChnlHst)+ChnlNum));	%Can vary from 0 to Inf
end
%Retreive an array of scaled currents of the 1st, 2nd, 3rd,.. n channel(s) (if necessary)
if VaryChnlCrnt==1	%vary (scale) <1> or not <0> the fully open currents of the 1st, 2nd, 3rd,.. n channel(s).
	MultiChnlCrnt=FitParameters((end-ChnlNum+1):end);	%Can vary from 0 to Inf
end

%------------------------------- calculate fitted distribution
HstFit=zeros(size(Hst));	%Initialize fitted distribution

%Initialize an array with indices of the current bin for every channel. It will be the runnin index array for the cycle through all the combinations
CombChnlBin=zeros(ChnlNum,1);

%Initialize an array with the accumulated (from left to right) probabilities to see the current combination of the channels' substates.
CombChnlProb=ones(ChnlNum,1);
CombChnlProb(1)=MultiChnlProb(1)*ChnlHst(1);
for i=2:ChnlNum	%Cycle through the tested substate combination of the channels
	CombChnlProb(i)=CombChnlProb(i-1)*MultiChnlProb(i)*ChnlHst(1);
end	%Cycle through the first substate of all the channels

%Initialize an array with the accumulated (from left to right) currents of see the current combination of the channels' substates.
CombChnlCrnt=zeros(ChnlNum,1);

CombCount=1;	%The counter for the current combination of substates
StartChnl=1;	%The channel from which recalculation starts this
%----------- Cycle though all the combinations of all the bins of all the channels that can be open
ChnlHstLength=length(ChnlHst);	%Total number of bins in the single channel histogram
CombCountMax=length(ChnlBinsMedians)^ChnlNum;	%Total number of all the possible combinations
for i=1:ChnlNum	%Cycle through the channels
	CombCountWeight(i)=ChnlHstLength^(ChnlNum-i);	%weight of the channel in the counter 
end
while CombCount <= CombCountMax	%number of the current combination not larger than the maximal number
	%Calculate the value of the combined counter
	CombChnlBin_old=CombChnlBin;
	remainder=CombCount-1;	%temporary value to calculate combined counter
	for i=1:ChnlNum	%Cycle through the channels
		CombChnlBin(i)=floor(remainder/CombCountWeight(i));
		remainder=remainder-CombChnlBin(i)*CombCountWeight(i);
	end	%Cycle through the channels
	CombChnlBin=CombChnlBin+1;
	%CombChnlBin'%!!!
	CombChnlBin_old=CombChnlBin_old-CombChnlBin;
	StartChnl=min(find(CombChnlBin_old~=0));	%Decide from which channel start recalculation next time
	
	%Calculate the current of the combination
	if StartChnl==1	%Substate of the first channel changed
		CombChnlCrnt(1)=MultiChnlCrnt(1)*ChnlBinsMedians(CombChnlBin(1));
	end
	for i=(max(StartChnl,2)):ChnlNum	%Cycle through the tested substate combination of the channels
		CombChnlCrnt(i)=CombChnlCrnt(i-1)+MultiChnlCrnt(i)*ChnlBinsMedians(CombChnlBin(i));
	end	%Cycle through the first substate of all the channels

	%Check, if the current fits into the range of the initial multichannel histogram Hst
	if (CombChnlCrnt(end)>Bins(1))	%The bin is above the lower boundary of the histogram Bins
		if ((CombChnlCrnt(end)<Bins(end)))	%The bin is below the higher boundary of the histogram Bins - Current fits into range
			%Calculate the probability of the combination
			if StartChnl==1	%Substate of the first channel changed
				CombChnlProb(1)=MultiChnlProb(1)*ChnlHst(CombChnlBin(1));
			end
			for i=(max(StartChnl,2)):ChnlNum	%Cycle through the tested substate combination of the channels
				CombChnlProb(i)=CombChnlProb(i-1)*MultiChnlProb(i)*ChnlHst(CombChnlBin(i));
			end	%Cycle through the first substate of all the channels
			
			%Add the probability to the corresponding final bin
			BinInHst=max(find(Bins<CombChnlCrnt(end)));	%Bin in the big histogram Hst corresponding to the amplitude of this substates combination
			HstFit(BinInHst)=HstFit(BinInHst)+CombChnlProb(end);
			
			CombCount=CombCount+1;	%Increase counter by one
		else	%The bin is above the higher boundary of the histogram Bins - Current is out of the histogram range
			%Predict the number of the excessive combinations
			MaxNonFirstSubChnl=max(find(CombChnlBin>1));	%The largest channel number, which is not in the first sub
			CombCountExcess=(ChnlHstLength-CombChnlBin(MaxNonFirstSubChnl))*CombCountWeight(MaxNonFirstSubChnl)+sum(ChnlHstLength*CombCountWeight((MaxNonFirstSubChnl+1):end));	%Number of excessive bins which will be above the boundary anyway
			
			CombCount=CombCount+CombCountExcess+1; %Set the counter to the next possible value
		end	%The bin is below the higher boundary of the histogram Bins
	else	%The bin is below the lower boundary of the histogram Bin
			CombCount=CombCount+1;	%Increase counter by one
	end	%The bin is above the lower boundary of the histogram Bin
	
end	%number of the current combination not larger than the maximal number



%------------------------------ compare fitted distribution with the original histogram
switch ScaleMode	%Mode of scaling and weighting for difference calculation
case 'Linear'
	%Compute difference with original distribution
	d=sum((HstFit(ComparisonRange)-Hst(ComparisonRange)).^2)^0.5;
case 'Log'
	HstFit=log10([loghst(HstFit)]);
	%Compute difference with original distribution
	d=sum((HstFit(ComparisonRange)-Hst(ComparisonRange)).^2)^0.5;
case 'LogMaxWeighted'
	HstFit=log10([loghst(HstFit)]);
	%Compute difference with original distribution
	d=HstFit-Hst;
	d=d.*WeightMatrix;
	d=sum(d(ComparisonRange).^2)^0.5;
end		%Mode of scaling and weighting for difference calculation

ecount_L=ecount_L+1;	%Add one to function evaluations count



%!!!!!!!!!
if IntermPlotStep~=0	%If Add control plot of the fit curve
	if round(ecount_L/IntermPlotStep)==ecount_L/IntermPlotStep	%time to add a curve
		%*** Creation bins' bunradies for plotting
		for i=1:(length(Bins)-1)
			BinsTp(i)=(Bins(i)+Bins(i+1))/2;	%Assigning a bin boundaries mean as a plot bin value
		end
		switch ScaleMode	%Mode of scaling and weighting for difference calculation
		case 'Linear'	%Need logscale
			HstFitP=log10([loghst(HstFit)]);
			HstP=log10([loghst(Hst)]);
			ChnlHstP=log10([loghst(ChnlHst)]);
		otherwise	%Already log scale
			HstFitP=HstFit;
			HstP=Hst;
			ChnlHstP=log10([loghst(ChnlHst)]);
		end	%Use logarithmic scale for difference calculation
		%toc
		if IntermPlotStep>0	%Add control plot of the fit curve
			hp=plot(BinsTp,HstFitP,'Color', [(1-IntermPlotStep/ecount_L),(1-2*abs(IntermPlotStep-ecount_L/2)/ecount_L),(IntermPlotStep/ecount_L)]);
			hp=plot(ChnlBinsMedians,ChnlHstP,'Color',[(1-IntermPlotStep/ecount_L),(1-2*abs(IntermPlotStep-ecount_L/2)/ecount_L),(IntermPlotStep/ecount_L)]/2);
			tstr=['print -dpng ''test_Hst.png'''];	%!!!
			eval(tstr);	%!!!
		else	%Add the first control plot of the fit curve 
			IntermPlotStep=-IntermPlotStep;
			figure;
			hp=plot(BinsTp,HstP,'Color','blue','LineWidth',2);
			hold on;
			hp=plot(BinsTp,HstFitP,'m');
			hp=plot(ChnlBinsMedians,ChnlHstP,'g');
		end	%Add control plot of the fit curve
		%tic
	end	%time to add a curve
end	%If Add control plot of the fit curve
% 
%!!!!!!!!!





function	Out=inf2range(A,B,In)

%Inputs:
%A - lower boundary
%B - upper boundary
%In - value from 0 to Inf

%Outputs:
%Out - value in the range

Out=A+(B-A)*(1./(1+exp(-In)));

function	Out=halfinf2range(A,B,In)

%Inputs:
%A - lower boundary
%B - upper boundary
%In - value from 0 to Inf

%Outputs:
%Out - value in the range

Out=B+(A-B)*exp(-In);

