%Program for simulation of activation curves in multichannel patch with channels dispersed in energy


%*****************   Initial parameters:
%User-defined
%DeltaE=58.9;	%initial opening energy difference for MscL, in kT
% DeltaE=40.88;	%initial opening energy difference for MscL, in kT
DeltaE=40.88/1.7*2;	%initial opening energy difference for MscL, in kT
%DeltaA=23.3;	%Expantion area of the channel - in nm^2
% DeltaA=30.02;	%Expantion area of the channel - in nm^2
DeltaA=30.02/1.7*2;	%Expantion area of the channel - in nm^2
% ExprDeltaE=32.41;	%initial opening energy difference for MscL, in kT
% ExprDeltaA=12.75;	%Expantion area of the channel - in nm^2
% ExprDeltaE=27.1;	%initial opening energy difference for MscL, in kT
ExprDeltaE=23.2;	%initial opening energy difference for MscL, in kT
% ExprDeltaA=20.0;	%Expantion area of the channel - in nm^2
ExprDeltaA=17.11;	%Expantion area of the channel - in nm^2
MinDeltaA=1;	%Minimal value for channel expansion area
%MinDeltaA=10;	%Minimal value for channel expansion area
%MaxDeltaA=40;	%Maximal value for channel expansion area
MaxDeltaA=23.3;	%Maximal value for channel expansion area
MindA=0;	%Minimal standard deviation in area between channels, nm^2
MaxdA=5;	%Maximal standard deviation in area between channels, nm^2
%MaxdA=DeltaA*0.15;	%Maximal standard deviation in area between channels, nm^2
AreaSteps=201;	%Number of steps in testing different area values between min and max
% RepeatAreaSteps=10;	%Number of repetitions for the dA range
T0=300;	%Temperature in kelvins
Nchan=50;	%Number of channels in patch
ChannelsNumber=[];
%ChannelsNumber(1:5)=1;
%ChannelsNumber(1:15)=50; 
%ChannelsNumber(16:30)=5;	%Number of channels in patch for sampling simulation
%ChannelsNumber(1:30)=50;	%Number of channels in patch for sampling simulation
%ChannelsNumber(1:11)=50;	%Number of channels in patch for sampling simulation
ChannelsNumber=[26 27 27 27 28 28 28 28 28 28 28 59 58 54 66 70 55 56 56 56 58 58 58 59 79 73 71 ];	%Number of channels in patch for sampling simulation
MinGamma=0;	%Minimal tension for making activation curve
MaxGamma=20;	%Maximal tension for making activation curve
%GammaSteps=100;	%Number of Tension steps in each activation curve
GammaSteps=200;	%Number of Tension steps in each activation curve
MindE=0;	%Minimal standard deviation in energy between channels, kT
MaxdE=10;	%Maximal standard deviation in energy between channels, kT
%MaxdE=DeltaE*0.15;	%Maximal standard deviation in energy between channels, kT
%dESampling=1.9;	%Standard deviation in energy between channels, for sampling, kT
%dESampling=2.9;	%Standard deviation in energy between channels, for sampling, kT
%dESampling=0;	%Standard deviation in energy between channels, for sampling, kT
%dESampling=DeltaE*0.05;	%Standard deviation in energy between channels, for sampling, kT
dESampling=DeltaE*0.07;	%Standard deviation in energy between channels, for sampling, kT
%dASampling=0.8;	%Standard deviation in area between channels, for sampling, nm^2
dASampling=1.2;	%Standard deviation in area between channels, for sampling, nm^2
%dASampling=0;	%Standard deviation in area between channels, for sampling, nm^2
%dETime=2.9;	%Standard deviation in energy of every channel with time - from one pressure step to another, kT
dETime=0;	%Standard deviation in energy of every channel with time - from one pressure step to another, kT
%dATime=0.1;	%Standard deviation in area of every channel with time - from one pressure step to another, nm^2
dATime=0;	%Standard deviation in area of every channel with time - from one pressure step to another, nm^2
% dESampling=1.9;	%Standard deviation in energy between channels, for sampling, kT
% dASampling=0.8;	%Standard deviation in area between channels, for sampling, nm^2
EnergySteps=11;	%number of steps in standard deviation of energy
MinPoPc=0.01;	%Minimal observable Po/Pc ratio
MaxPoPc=100;	%Maximal observable Po/Pc ratio
PlotInterm=0;	%plot intermediate results of calculation
PlotAreaEffect=0;	%Plot results of area change
RandomizeEveryStep=1;	%Regenerate random numbers at every dispersion value

CalcMode='dESampling';	%Mode of calculations:  'Area' 'dE' 'dESampling' 'AreaEnergy' 'dA' 'dEdA' 'dASampling' 'dEdASampling' 'dA_dASampling'

dE=[]; Po=[]; Gamma=[]; dEhalf=[]; DeltaAs=[]; dA=[]; 

%Parameters
kb=1.380658E-23;	%Boltzmann's constant, J/K
kT=kb*T0;	%kT value, in J
Gamma05=4.0474*DeltaE/DeltaA;	%Tension of half-saturation of activation curve, in dyne/cm
g=1:GammaSteps;	Gamma(g)=MinGamma+(MaxGamma-MinGamma)*(g-1)/(GammaSteps-1);	%Vector of tension values
d=1:EnergySteps; dE(d)=MindE+(MaxdE-MindE)*(d-1)/(EnergySteps-1);	%Current value of the standard deviation of energy between channels, in kT
r=1:AreaSteps; dA(r)=MindA+(MaxdA-MindA)*(r-1)/(AreaSteps-1);	%Current value of the standard deviation of energy between channels, in kT
dEs=randn([Nchan 1]);	%Generate matrix of random energy deviations
dAs=randn([Nchan 1]);	%Generate matrix of random area deviations
a=1:AreaSteps; DeltaAs(a)=MinDeltaA+(MaxDeltaA-MinDeltaA)*(a-1)/(AreaSteps-1);	%Array of areas


switch CalcMode	%Mode of calculation
case 'dESampling'	%Multiple Activation curves at fixed energy dispersion. Fixed DeltaE and DeltaA
	ApDeltaE=[]; ApDeltaA=[];  ApGamma05=[];
	for d=1:length(ChannelsNumber)	%Cycle throught the increasing values of the standard deviation of energy between channels
		dEs=randn([ChannelsNumber(d) 1]);	%Generate matrix of random energy deviations
		DeltaEs=DeltaE+dEs*dESampling;	%Current matrix of energies of channel opening kT
		DeltaEs_time=zeros(size(DeltaEs));	%Initialize matrix for parameter variation for every timestep
		for g=1:GammaSteps	%Cycle through the tension steps
			if dETime>0	%There is variation of channel parameters in time - for every pressure step
				DeltaEs_time=dETime*randn([ChannelsNumber(d) 1]);	%Initialize matrix for parameter variation for every timestep
			else
			end
			Pos=1./(1+exp((DeltaEs+DeltaEs_time)-(1E-21)*Gamma(g)*DeltaA/kT));	%Matrix of  probabilities to be open at the given value of energy dispersion and tension value for every channel. 1E-21 is conversion factor from (nm^2*dynes/cm) to J
			Po(d,g)=mean(Pos);	%Average (per patch) probability to be open at the given value of energy dispersion and tension value
		end 	%Cycle through the tension steps
	end	%Cycle throught the increasing values of the standard deviation of energy between channels
	
	Pot=Po; Pot(Pot==1)=max(Pot(Pot<1)); Pot(Pot==0)=min(Pot(Pot>0));	%remove values which will give infinity and zeros
	PoPc=Pot./(1-Pot);	%Po/Pc ratio
	PoPct=PoPc; PoPct(PoPct>MaxPoPc)=MaxPoPc; PoPct(PoPct<MinPoPc)=MinPoPc;	%remove values which will give infinity and zeros
	
	%***************** Make a linear fit and extract apparent energy and area
	for  d=1:length(ChannelsNumber)	%Cycle throught the sample patches
		PointsInRange=find((PoPc(d,:)>=MinPoPc)&(PoPc(d,:)<=MaxPoPc));	%Select pressure steps fitting into the observable range
		v = polyfit(Gamma(PointsInRange),log(PoPc(d,PointsInRange)),1);	%Make a linear fit and extract parameters - ApDeltaE in kT, ApDeltaA in 1/(kT*dynes/cm)
		ApDeltaA(d)=v(1);
		ApDeltaE(d)=-v(2);
	end	%Cycle throught the sample patches
	ApGamma05=ApDeltaE./ApDeltaA;
	ApDeltaA=ApDeltaA*kT*(1E21);	%Conversion to nm^2
	
	
	figure
	hold on
	plot([DeltaA DeltaA],[DeltaE-dESampling DeltaE+dESampling],'k-');
	plot([0.995*DeltaA 1.005*DeltaA],[DeltaE+dESampling DeltaE+dESampling],'k-');
	plot([0.995*DeltaA 1.005*DeltaA],[DeltaE-dESampling DeltaE-dESampling],'k-');
	xlabel('DeltaA, nm^2','Interpreter','none')
	ylabel('DeltaE, kT','Interpreter','none')
	plot(ApDeltaA,ApDeltaE,'k^','MarkerFaceColor','k','MarkerSize',6);
	plot(mean(ApDeltaA),mean(ApDeltaE),'wo','MarkerSize',12,'MarkerFaceColor','k');
	plot(DeltaA,DeltaE,'k^','MarkerSize',12,'MarkerFaceColor','w');
	plot(ExprDeltaA,ExprDeltaE,'ko','MarkerSize',12,'MarkerFaceColor','w');
	axis([0 DeltaA*1.1 0 DeltaE*1.1]);
	hold off
    
    figure
	plot(Gamma,PoPc,'k-')
	%axis([4 16 0.00001 100000]);
	axis([0 16 0.00001 100000]);
	set(gca,'YScale','log');
	xlabel('Gamma, dyne/cm','Interpreter','none')
	ylabel('Po/Pc','Interpreter','none')
	hold on
	plot([0 16],[0.01 0.01],'k:')
	plot([0 16],[100 100],'k:')
	hold off

	
case 'dASampling'	%Multiple Activation curves at fixed area dispersion. Fixed DeltaE and DeltaA
	ApDeltaE=[]; ApDeltaA=[];  ApGamma05=[];
	for d=1:length(ChannelsNumber)	%Cycle throught the increasing values of the standard deviation of energy between channels
		dAs=randn([ChannelsNumber(d) 1]);	%Generate matrix of random energy deviations
		DeltaAs=DeltaA+dAs*dASampling;	%Current matrix of energies of channel opening kT
		DeltaAs_time=zeros(size(DeltaAs));	%Initialize matrix for parameter variation for every timestep
		for g=1:GammaSteps	%Cycle through the tension steps
			if dATime>0	%There is variation of channel parameters in time - for every pressure step
				DeltaAs_time=dATime*randn([ChannelsNumber(d) 1]);	%Initialize matrix for parameter variation for every timestep
			else
			end
			Pos=1./(1+exp(DeltaE-(1E-21)*Gamma(g)*(DeltaAs+DeltaAs_time)/kT));	%Matrix of  probabilities to be open at the given value of energy dispersion and tension value for every channel. 1E-21 is conversion factor from (nm^2*dynes/cm) to J
			Po(d,g)=mean(Pos);	%Average (per patch) probability to be open at the given value of energy dispersion and tension value
		end 	%Cycle through the tension steps
	end	%Cycle throught the increasing values of the standard deviation of energy between channels
	
	Pot=Po; Pot(Pot==1)=max(Pot(Pot<1)); Pot(Pot==0)=min(Pot(Pot>0));	%remove values which will give infinity and zeros
	PoPc=Pot./(1-Pot);	%Po/Pc ratio
	PoPct=PoPc; PoPct(PoPct>MaxPoPc)=MaxPoPc; PoPct(PoPct<MinPoPc)=MinPoPc;	%remove values which will give infinity and zeros
	
	%***************** Make a linear fit and extract apparent energy and area
	for  d=1:length(ChannelsNumber)	%Cycle throught the sample patches
		PointsInRange=find((PoPc(d,:)>=MinPoPc)&(PoPc(d,:)<=MaxPoPc));	%Select pressure steps fitting into the observable range
		v = polyfit(Gamma(PointsInRange),log(PoPc(d,PointsInRange)),1);	%Make a linear fit and extract parameters - ApDeltaE in kT, ApDeltaA in 1/(kT*dynes/cm)
		ApDeltaA(d)=v(1);
		ApDeltaE(d)=-v(2);
	end	%Cycle throught the sample patches
	ApGamma05=ApDeltaE./ApDeltaA;
	ApDeltaA=ApDeltaA*kT*(1E21);	%Conversion to nm^2
	
	figure
	hold on
	plot([DeltaA-dASampling DeltaA+dASampling],[DeltaE DeltaE],'k-');
	plot([DeltaA+dASampling DeltaA+dASampling],[0.992*DeltaE 1.008*DeltaE],'k-');
	plot([DeltaA-dASampling DeltaA-dASampling],[0.992*DeltaE 1.008*DeltaE],'k-');
	xlabel('DeltaA, nm^2','Interpreter','none')
	ylabel('DeltaE, kT','Interpreter','none')
	plot(ApDeltaA,ApDeltaE,'k^','MarkerFaceColor','k','MarkerSize',6);
	plot(mean(ApDeltaA),mean(ApDeltaE),'wo','MarkerSize',12,'MarkerFaceColor','k');
	plot(DeltaA,DeltaE,'k^','MarkerSize',12,'MarkerFaceColor','w');
	plot(ExprDeltaA,ExprDeltaE,'ko','MarkerSize',12,'MarkerFaceColor','w');
	axis([0 DeltaA*1.1 0 DeltaE*1.1]);
	hold off
	
% 	figure
% 	hp=surfl(Gamma,1:length(ChannelsNumber),PoPct);
% 	xlabel('Gamma, dyne/cm','Interpreter','none')
% 	ylabel('Sample, #','Interpreter','none')
% 	zlabel('Po/Pc','Interpreter','none')
% 	set(gca,'ZScale','log');
	
	figure
	hp=plot(Gamma,PoPct,'.-');
	xlabel('Gamma, dyne/cm','Interpreter','none')
	ylabel('Po/Pc','Interpreter','none')
	set(gca,'YScale','log');
	

case 'dA_dASampling'	%Repetitions of (Multiple Activation curves at fixed area dispersion. Fixed DeltaE and DeltaA) at different dA
    
    
		ApDeltaE=[]; ApDeltaA=[]; ApGamma05=[];
		ApDeltaE_All=[]; ApDeltaA_All=[]; ApGamma05_All=[];dA_All=[];
		for r=1:AreaSteps	%Cycle throught the increasing values of the standard deviation of area between channels

            ApDeltaE_s=[]; ApDeltaA_s=[];  ApGamma05_s=[];
            for d=1:length(ChannelsNumber)	%Cycle throught the increasing values of the standard deviation of energy between channels
                dAs=randn([ChannelsNumber(d) 1]);	%Generate matrix of random energy deviations
                DeltaAs=DeltaA+dAs*dA(r);	%Current matrix of energies of channel opening kT
                for g=1:GammaSteps	%Cycle through the tension steps
                    Pos=1./(1+exp(DeltaE-(1E-21)*Gamma(g)*DeltaAs/kT));	%Matrix of  probabilities to be open at the given value of energy dispersion and tension value for every channel. 1E-21 is conversion factor from (nm^2*dynes/cm) to J
                    Po(d,g)=mean(Pos);	%Average (per patch) probability to be open at the given value of energy dispersion and tension value
                end 	%Cycle through the tension steps
            end	%Cycle throught the increasing values of the standard deviation of energy between channels
            
            Pot=Po; Pot(Pot==1)=max(Pot(Pot<1)); Pot(Pot==0)=min(Pot(Pot>0));	%remove values which will give infinity and zeros
            PoPc=Pot./(1-Pot);	%Po/Pc ratio
            PoPct=PoPc; PoPct(PoPct>MaxPoPc)=MaxPoPc; PoPct(PoPct<MinPoPc)=MinPoPc;	%remove values which will give infinity and zeros
            
            %***************** Make a linear fit and extract apparent energy and area
            for  d=1:length(ChannelsNumber)	%Cycle throught the sample patches
                PointsInRange=find((PoPc(d,:)>=MinPoPc)&(PoPc(d,:)<=MaxPoPc));	%Select pressure steps fitting into the observable range
                v = polyfit(Gamma(PointsInRange),log(PoPc(d,PointsInRange)),1);	%Make a linear fit and extract parameters - ApDeltaE in kT, ApDeltaA in 1/(kT*dynes/cm)
                ApDeltaA_s(d)=v(1);
                ApDeltaE_s(d)=-v(2);
            end	%Cycle throught the sample patches
            ApGamma05_s=ApDeltaE_s./ApDeltaA_s;
            ApDeltaA_s=ApDeltaA_s*kT*(1E21);	%Conversion to nm^2
            
            ApGamma05(r)=mean(ApGamma05_s);
			ApDeltaA(r)=mean(ApDeltaA_s);
			ApDeltaE(r)=mean(ApDeltaE_s);
            ApGamma05_All=[ApGamma05_All,ApGamma05_s];
			ApDeltaA_All=[ApDeltaA_All,ApDeltaA_s];
			ApDeltaE_All=[ApDeltaE_All,ApDeltaE_s];
            dA_All=[dA_All,dA(r)*ones(size(ApDeltaA_s))];
            
		end	%Cycle throught the increasing values of the standard deviation of area between channels
		
    
    
	figure
	plot(dA,[ApDeltaE;ApDeltaA;ApGamma05]);
	xlabel('dA, nm^2','Interpreter','none')
	ylabel('DeltaE, kT;  DeltaA, nm^2;  Gamma, dyne/cm','Interpreter','none')
	
	figure
	plot(dA,ApDeltaA,'b.');
	xlabel('dA, nm^2','Interpreter','none')
	ylabel('DeltaA, nm^2','Interpreter','none')
	
	figure
	plot(dA_All,ApDeltaA_All,'r.');
	xlabel('dA, nm^2','Interpreter','none')
	ylabel('DeltaA, nm^2','Interpreter','none')
    hold on
 	plot(dA,ApDeltaA,'bo');
    hold off

    figure
	plot3(ApDeltaE_All,ApDeltaA_All,ApGamma05_All,'r.');
	xlabel('DeltaE, kT','Interpreter','none')
	ylabel('DeltaA, nm^2','Interpreter','none')
	zlabel('Gamma, dyne/cm','Interpreter','none')
    hold on
 	plot3(ApDeltaE,ApDeltaA,ApGamma05,'bo');
    hold off

	figure
	plot(dA_All,ApGamma05_All,'r.');
	xlabel('dA, nm^2','Interpreter','none')
	ylabel('Gamma, dyne/cm','Interpreter','none')
    hold on
 	plot(dA,ApGamma05,'bo');
    hold off
    
    figure
	plot3(ApDeltaE_All,ApDeltaA_All,dA_All,'r.');
	xlabel('DeltaE, kT','Interpreter','none')
	ylabel('DeltaA, nm^2','Interpreter','none')
	zlabel('dA, nm^2','Interpreter','none')
    hold on
 	plot3(ApDeltaE,ApDeltaA,dA,'bo');
    hold off



case 'dEdASampling'	%Multiple Activation curves at fixed energy and area dispersions. Fixed DeltaE and DeltaA
	ApDeltaE=[]; ApDeltaA=[];  ApGamma05=[]; dEsList=[]; dAsList=[];
	for d=1:length(ChannelsNumber)	%Cycle throught the increasing values of the standard deviation of energy between channels
		dEs=randn([ChannelsNumber(d) 1]);	%Generate matrix of random energy deviations
		DeltaEs=DeltaE+dEs*dESampling;	%Current matrix of energies of channel opening kT
		dAs=randn([ChannelsNumber(d) 1]);	%Generate matrix of random energy deviations
		DeltaAs=DeltaA+dAs*dASampling;	%Current matrix of energies of channel opening kT
		dEsList=[dEsList(:);DeltaEs(:)]; dAsList=[dAsList(:);DeltaAs(:)]; 
		DeltaEs_time=zeros(size(DeltaEs));	%Initialize matrix for parameter variation for every timestep
		DeltaAs_time=zeros(size(DeltaAs));	%Initialize matrix for parameter variation for every timestep
		for g=1:GammaSteps	%Cycle through the tension steps
			if dATime>0	%There is variation of channel parameters in time - for every pressure step
				DeltaAs_time=dATime*randn([ChannelsNumber(d) 1]);	%Initialize matrix for parameter variation for every timestep
			else
			end
			if dETime>0	%There is variation of channel parameters in time - for every pressure step
				DeltaEs_time=dETime*randn([ChannelsNumber(d) 1]);	%Initialize matrix for parameter variation for every timestep
			else
			end
			Pos=1./(1+exp((DeltaEs+DeltaEs_time)-(1E-21)*Gamma(g)*(DeltaAs+DeltaAs_time)/kT));	%Matrix of  probabilities to be open at the given value of energy dispersion and tension value for every channel. 1E-21 is conversion factor from (nm^2*dynes/cm) to J
			Po(d,g)=mean(Pos);	%Average (per patch) probability to be open at the given value of energy dispersion and tension value
		end 	%Cycle through the tension steps
	end	%Cycle throught the increasing values of the standard deviation of energy between channels
	
	Pot=Po; Pot(Pot==1)=max(Pot(Pot<1)); Pot(Pot==0)=min(Pot(Pot>0));	%remove values which will give infinity and zeros
	PoPc=Pot./(1-Pot);	%Po/Pc ratio
	PoPct=PoPc; PoPct(PoPct>MaxPoPc)=MaxPoPc; PoPct(PoPct<MinPoPc)=MinPoPc;	%remove values which will give infinity and zeros
	
	%***************** Make a linear fit and extract apparent energy and area
	for  d=1:length(ChannelsNumber)	%Cycle throught the sample patches
		PointsInRange=find((PoPc(d,:)>=MinPoPc)&(PoPc(d,:)<=MaxPoPc));	%Select pressure steps fitting into the observable range
		v = polyfit(Gamma(PointsInRange),log(PoPc(d,PointsInRange)),1);	%Make a linear fit and extract parameters - ApDeltaE in kT, ApDeltaA in 1/(kT*dynes/cm)
		ApDeltaA(d)=v(1);
		ApDeltaE(d)=-v(2);
	end	%Cycle throught the sample patches
	ApGamma05=ApDeltaE./ApDeltaA;
	ApDeltaA=ApDeltaA*kT*(1E21);	%Conversion to nm^2
	
	
% 	figure
% 	hp=surfl(Gamma,1:length(ChannelsNumber),Po);
% 	xlabel('Gamma, dyne/cm','Interpreter','none')
% 	ylabel('Sample, #','Interpreter','none')
% 	zlabel('Po','Interpreter','none')
% 	
% 	figure
% 	hp=surfl(Gamma,1:length(ChannelsNumber),PoPct);
% 	xlabel('Gamma, dyne/cm','Interpreter','none')
% 	ylabel('Sample, #','Interpreter','none')
% 	zlabel('Po/Pc','Interpreter','none')
% 	set(gca,'ZScale','log');
% 	
% 	PoPct2=PoPc; PoPct2(PoPct2>MaxPoPc*100)=MaxPoPc*100; PoPct2(PoPct2<MinPoPc/100)=MinPoPc/100;	%remove values which will give infinity and zeros
% 	PoPcAlpha=ones(size(PoPc));
% 	PoPcAlpha(PoPc>1)=0;
% 	
% 	PoPcp=log10(PoPct2);
% 	PoPcAlpha=ones(size(PoPc));
% 	PoPcAlpha(PoPc>MaxPoPc*30)=max(0,1-(PoPc(PoPc>MaxPoPc*30)-MaxPoPc*30)/(MaxPoPc*100-MaxPoPc*30));
% 	PoPcAlpha(PoPc<MinPoPc/30)=max(0,1-(PoPc(PoPc<MinPoPc/30)-MinPoPc/30)/(MinPoPc/100-MinPoPc/30));
% 	
% 	PoPcSlope=diff(PoPcp,1,2);
% 	PoPcSlope(:,end+1)=PoPcSlope(:,end);
% 	figure
% 	s = surface(Gamma,1:length(ChannelsNumber),PoPcp,'cdata',PoPcSlope);           
% 	shading interp
% 	set(s,'edgecolor','interp','edgealpha','interp','facealpha',0,'alphadata',PoPcAlpha);
% 	
% 	set(s,'backfacelighting','unlit');
% 	set(s,'MeshStyle','row','LineWidth',1.5);
% 	colormap(jet);
% 	xlabel('Gamma, dyne/cm','Interpreter','none')
% 	ylabel('Sample, #','Interpreter','none')
% 	zlabel('log of Po/Pc','Interpreter','none')
% 	set(gca,'XGrid','on')
% 	set(gca,'YGrid','on')
% 	set(gca,'ZGrid','on')
% 	lighting gouraud; 

% 	figure
% 	plot(1:length(ChannelsNumber),[ApDeltaE;ApDeltaA;ApGamma05]);
% 	xlabel('Sample, #','Interpreter','none')
% 	ylabel('DeltaE, kT;  DeltaA, nm^2;  Gamma, dyne/cm','Interpreter','none')

	figure
	hold on
	plot(dAsList,dEsList,'k.','MarkerSize',4);
	xlabel('DeltaA, nm^2','Interpreter','none')
	ylabel('DeltaE, kT','Interpreter','none')
	plot(ApDeltaA,ApDeltaE,'k^','MarkerFaceColor','k','MarkerSize',6);
	plot(mean(ApDeltaA),mean(ApDeltaE),'wo','MarkerSize',12,'MarkerFaceColor','k');
	plot(DeltaA,DeltaE,'k^','MarkerSize',12,'MarkerFaceColor','w');
	plot(ExprDeltaA,ExprDeltaE,'ko','MarkerSize',12,'MarkerFaceColor','w');
	axis([0 DeltaA*1.1 0 DeltaE*1.1]);
	hold off
    
    ApGamma05_mean=mean(ApGamma05)
    ApGamma05_std=std(ApGamma05)


	
case 'dE'	%Activation curves at different energy dispersions. Fixed DeltaE and DeltaA
		ApDeltaE=[]; ApDeltaA=[];  ApGamma05=[];
		for d=1:EnergySteps	%Cycle throught the increasing values of the standard deviation of energy between channels
			if RandomizeEveryStep==1	%Regenerate random numbers at every dispersion value
				dEs=randn([Nchan 1]);	%Generate matrix of random energy deviations
			end	%Regenerate random numbers at every dispersion value
			DeltaEs=DeltaE+dEs*dE(d);	%Current matrix of energies of channel opening kT
			for g=1:GammaSteps	%Cycle through the tension steps
				Pos=1./(1+exp(DeltaEs-(1E-21)*Gamma(g)*DeltaA/kT));	%Matrix of  probabilities to be open at the given value of energy dispersion and tension value for every channel. 1E-21 is conversion factor from (nm^2*dynes/cm) to J
				Po(d,g)=mean(Pos);	%Average (per patch) probability to be open at the given value of energy dispersion and tension value
			end 	%Cycle through the tension steps
		end	%Cycle throught the increasing values of the standard deviation of energy between channels
		
		Pot=Po; Pot(Pot==1)=max(Pot(Pot<1)); Pot(Pot==0)=min(Pot(Pot>0));	%remove values which will give infinity and zeros
		PoPc=Pot./(1-Pot);	%Po/Pc ratio
		PoPct=PoPc; PoPct(PoPct>MaxPoPc)=MaxPoPc; PoPct(PoPct<MinPoPc)=MinPoPc;	%remove values which will give infinity and zeros
		
		%***************** Make a linear fit and extract apparent energy and area
		for  d=1:EnergySteps	%Cycle throught the increasing values of the standard deviation of energy between channels
			PointsInRange=find((PoPc(d,:)>=MinPoPc)&(PoPc(d,:)<=MaxPoPc));	%Select pressure steps fitting into the observable range
			v = polyfit(Gamma(PointsInRange),log(PoPc(d,PointsInRange)),1);	%Make a linear fit and extract parameters - ApDeltaE in kT, ApDeltaA in 1/(kT*dynes/cm)
			ApDeltaA(d)=v(1);
			ApDeltaE(d)=-v(2);
		end	%Cycle throught the increasing values of the standard deviation of energy between channels
		ApGamma05=ApDeltaE./ApDeltaA;
		ApDeltaA=ApDeltaA*kT*(1E21);	%Conversion to nm^2
	
	
% 	figure
% 	hp=surfl(Gamma,dE,Po);
% 	xlabel('Gamma, dyne/cm','Interpreter','none')
% 	ylabel('dE, kT','Interpreter','none')
% 	zlabel('Po','Interpreter','none')
% 	
% 	figure
% 	hp=surfl(Gamma,dE,PoPct);
% 	xlabel('Gamma, dyne/cm','Interpreter','none')
% 	ylabel('dE, kT','Interpreter','none')
% 	zlabel('Po/Pc','Interpreter','none')
% 	set(gca,'ZScale','log');
% 	
% 	PoPct2=PoPc; PoPct2(PoPct2>MaxPoPc*100)=MaxPoPc*100; PoPct2(PoPct2<MinPoPc/100)=MinPoPc/100;	%remove values which will give infinity and zeros
% 	PoPcAlpha=ones(size(PoPc));
% 	PoPcAlpha(PoPc>1)=0;
% 	
% 	PoPcp=log10(PoPct2);
% 	PoPcAlpha=ones(size(PoPc));
% 	PoPcAlpha(PoPc>MaxPoPc*30)=max(0,1-(PoPc(PoPc>MaxPoPc*30)-MaxPoPc*30)/(MaxPoPc*100-MaxPoPc*30));
% 	PoPcAlpha(PoPc<MinPoPc/30)=max(0,1-(PoPc(PoPc<MinPoPc/30)-MinPoPc/30)/(MinPoPc/100-MinPoPc/30));
% 	
% 	PoPcSlope=diff(PoPcp,1,2);
% 	PoPcSlope(:,end+1)=PoPcSlope(:,end);
% 	figure
% 	s = surface(Gamma,dE,PoPcp,'cdata',PoPcSlope);           
% 	shading interp
% 	set(s,'edgecolor','interp','edgealpha','interp','facealpha',0,'alphadata',PoPcAlpha);
% 	
% 	set(s,'backfacelighting','unlit');
% 	set(s,'MeshStyle','row','LineWidth',1.5);
% 	colormap(jet);
% 	xlabel('Gamma, dyne/cm','Interpreter','none')
% 	ylabel('dE, kT','Interpreter','none')
% 	zlabel('log of Po/Pc','Interpreter','none')
% 	set(gca,'XGrid','on')
% 	set(gca,'YGrid','on')
% 	set(gca,'ZGrid','on')
% 	lighting gouraud; 
% 
	figure
	plot(dE,[ApDeltaE;ApDeltaA;ApGamma05]);
	xlabel('dE, kT','Interpreter','none')
	ylabel('DeltaE, kT;  DeltaA, nm^2;  Gamma, dyne/cm','Interpreter','none')
	
	figure
	plot(Gamma,PoPc,'k-')
	%axis([4 16 0.00001 100000]);
	axis([0 16 0.00001 100000]);
	set(gca,'YScale','log');
	xlabel('Gamma, dyne/cm','Interpreter','none')
	ylabel('Po/Pc','Interpreter','none')
	hold on
	plot([0 16],[0.01 0.01],'k:')
	plot([0 16],[100 100],'k:')
	hold off
	
case 'dA'	%Activation curves at different Area dispersions. Fixed DeltaE and DeltaA
		ApDeltaE=[]; ApDeltaA=[]; ApGamma05=[];
		for r=1:AreaSteps	%Cycle throught the increasing values of the standard deviation of area between channels
			if RandomizeEveryStep==1	%Regenerate random numbers at every dispersion value
				dAs=randn([Nchan 1]);	%Generate matrix of random area deviations
			end
			DeltaAs=DeltaA+dAs*dA(r);	%Current matrix of energies of channel opening kT
			for g=1:GammaSteps	%Cycle through the tension steps
				Pos=1./(1+exp(DeltaE-(1E-21)*Gamma(g)*DeltaAs/kT));	%Matrix of  probabilities to be open at the given value of energy dispersion and tension value for every channel. 1E-21 is conversion factor from (nm^2*dynes/cm) to J
				Po(r,g)=mean(Pos);	%Average (per patch) probability to be open at the given value of energy dispersion and tension value
			end 	%Cycle through the tension steps
		end	%Cycle throught the increasing values of the standard deviation of area between channels
		
		Pot=Po; Pot(Pot==1)=max(Pot(Pot<1)); Pot(Pot==0)=min(Pot(Pot>0));	%remove values which will give infinity and zeros
		PoPc=Pot./(1-Pot);	%Po/Pc ratio
		PoPct=PoPc; PoPct(PoPct>MaxPoPc)=MaxPoPc; PoPct(PoPct<MinPoPc)=MinPoPc;	%remove values which will give infinity and zeros
		
		%***************** Make a linear fit and extract apparent energy and area
		for  r=1:AreaSteps	%Cycle throught the increasing values of the standard deviation of energy between channels
			PointsInRange=find((PoPc(r,:)>=MinPoPc)&(PoPc(r,:)<=MaxPoPc));	%Select pressure steps fitting into the observable range
			v = polyfit(Gamma(PointsInRange),log(PoPc(r,PointsInRange)),1);	%Make a linear fit and extract parameters - ApDeltaE in kT, ApDeltaA in 1/(kT*dynes/cm)
			ApDeltaA(r)=v(1);
			ApDeltaE(r)=-v(2);
		end	%Cycle throught the increasing values of the standard deviation of energy between channels
		ApGamma05=ApDeltaE./ApDeltaA;
		ApDeltaA=ApDeltaA*kT*(1E21);	%Conversion to nm^2
% 	
% 	
% 	figure
% 	hp=surfl(Gamma,dA,Po);
% 	xlabel('Gamma, dyne/cm','Interpreter','none')
% 	ylabel('dA, nm^2','Interpreter','none')
% 	zlabel('Po','Interpreter','none')
% 	
% 	figure
% 	hp=surfl(Gamma,dA,PoPct);
% 	xlabel('Gamma, dyne/cm','Interpreter','none')
% 	ylabel('dA, nm^2','Interpreter','none')
% 	zlabel('Po/Pc','Interpreter','none')
% 	set(gca,'ZScale','log');
% 	
% 	PoPct2=PoPc; PoPct2(PoPct2>MaxPoPc*100)=MaxPoPc*100; PoPct2(PoPct2<MinPoPc/100)=MinPoPc/100;	%remove values which will give infinity and zeros
% 	PoPcAlpha=ones(size(PoPc));
% 	PoPcAlpha(PoPc>1)=0;
% 	
% 	PoPcp=log10(PoPct2);
% 	PoPcAlpha=ones(size(PoPc));
% 	PoPcAlpha(PoPc>MaxPoPc*30)=max(0,1-(PoPc(PoPc>MaxPoPc*30)-MaxPoPc*30)/(MaxPoPc*100-MaxPoPc*30));
% 	PoPcAlpha(PoPc<MinPoPc/30)=max(0,1-(PoPc(PoPc<MinPoPc/30)-MinPoPc/30)/(MinPoPc/100-MinPoPc/30));
% 	
% 	PoPcSlope=diff(PoPcp,1,2);
% 	PoPcSlope(:,end+1)=PoPcSlope(:,end);
% 	figure
% 	s = surface(Gamma,dA,PoPcp,'cdata',PoPcSlope);           
% 	shading interp
% 	set(s,'edgecolor','interp','edgealpha','interp','facealpha',0,'alphadata',PoPcAlpha);
% 	
% 	set(s,'backfacelighting','unlit');
% 	set(s,'MeshStyle','row','LineWidth',1.5);
% 	colormap(jet);
% 	xlabel('Gamma, dyne/cm','Interpreter','none')
% 	ylabel('dA, nm^2','Interpreter','none')
% 	zlabel('log of Po/Pc','Interpreter','none')
% 	set(gca,'XGrid','on')
% 	set(gca,'YGrid','on')
% 	set(gca,'ZGrid','on')
% 	lighting gouraud; 
% 
	figure
	plot(dA,[ApDeltaE;ApDeltaA;ApGamma05]);
	xlabel('dA, nm^2','Interpreter','none')
	ylabel('DeltaE, kT;  DeltaA, nm^2;  Gamma, dyne/cm','Interpreter','none')
	
	figure
	plot(Gamma,PoPc,'k-')
	axis([4 16 0.00001 100000]);
	set(gca,'YScale','log');
	xlabel('Gamma, dyne/cm','Interpreter','none')
	ylabel('Po/Pc','Interpreter','none')
	hold on
	plot([4 16],[0.01 0.01],'k:')
	plot([4 16],[100 100],'k:')
	hold off
	
case 'dEdA'	%Activation curves at different Area and Energy dispersions. Fixed DeltaE and DeltaA
		ApDeltaE=[]; ApDeltaA=[]; ApGamma05=[];
		for d=1:EnergySteps	%Cycle throught the increasing values of the standard deviation of energy between channels
			if RandomizeEveryStep==1	%Regenerate random numbers at every dispersion value
				dEs=randn([Nchan 1]);	%Generate matrix of random energy deviations
			end	%Regenerate random numbers at every dispersion value
			DeltaEs=DeltaE+dEs*dE(d);	%Current matrix of energies of channel opening kT
			for r=1:AreaSteps	%Cycle throught the increasing values of the standard deviation of area between channels
				if RandomizeEveryStep==1	%Regenerate random numbers at every dispersion value
					dAs=randn([Nchan 1]);	%Generate matrix of random area deviations
				end
				DeltaAs=DeltaA+dAs*dA(r);	%Current matrix of energies of channel opening kT
				for g=1:GammaSteps	%Cycle through the tension steps
					Pos=1./(1+exp(DeltaEs-(1E-21)*Gamma(g)*DeltaAs/kT));	%Matrix of  probabilities to be open at the given value of energy dispersion and tension value for every channel. 1E-21 is conversion factor from (nm^2*dynes/cm) to J
					Po(d,r,g)=mean(Pos);	%Average (per patch) probability to be open at the given value of energy dispersion and tension value
				end 	%Cycle through the tension steps
			end	%Cycle throught the increasing values of the standard deviation of Area between channels
		end	%Cycle throught the increasing values of the standard deviation of energy between channels
		
		
		Pot=Po; Pot(Pot==1)=max(Pot(Pot<1)); Pot(Pot==0)=min(Pot(Pot>0));	%remove values which will give infinity and zeros
		PoPc=Pot./(1-Pot);	%Po/Pc ratio
		PoPct=PoPc; PoPct(PoPct>MaxPoPc)=MaxPoPc; PoPct(PoPct<MinPoPc)=MinPoPc;	%remove values which will give infinity and zeros
		
		%***************** Make a linear fit and extract apparent energy and area
		for d=1:EnergySteps	%Cycle throught the increasing values of the standard deviation of energy between channels
			for r=1:AreaSteps	%Cycle throught the increasing values of the standard deviation of energy between channels
				PointsInRange=find((PoPc(d,r,:)>=MinPoPc)&(PoPc(d,r,:)<=MaxPoPc));	%Select pressure steps fitting into the observable range
				tm=log(PoPc(d,r,PointsInRange));
				tm=tm(:)';
				v = polyfit(Gamma(PointsInRange),tm,1);	%Make a linear fit and extract parameters - ApDeltaE in kT, ApDeltaA in 1/(kT*dynes/cm)
				ApDeltaA(d,r)=v(1);
				ApDeltaE(d,r)=-v(2);
			end	%Cycle throught the increasing values of the standard deviation of area between channels
		end	%Cycle throught the increasing values of the standard deviation of energy between channels
		
		ApGamma05=ApDeltaE./ApDeltaA;
		ApDeltaA=ApDeltaA*kT*(1E21);	%Conversion to nm^2
	
	
	
% 	PoPct2=PoPc; PoPct2(PoPct2>MaxPoPc*100)=MaxPoPc*100; PoPct2(PoPct2<MinPoPc/100)=MinPoPc/100;	%remove values which will give infinity and zeros
% 	PoPcAlpha=ones(size(PoPc));
% 	PoPcAlpha(PoPc>1)=0;
% 	
% 	PoPcp=log10(PoPct2);
% 	PoPcAlpha=ones(size(PoPc));
% 	PoPcAlpha(PoPc>MaxPoPc*30)=max(0,1-(PoPc(PoPc>MaxPoPc*30)-MaxPoPc*30)/(MaxPoPc*100-MaxPoPc*30));
% 	PoPcAlpha(PoPc<MinPoPc/30)=max(0,1-(PoPc(PoPc<MinPoPc/30)-MinPoPc/30)/(MinPoPc/100-MinPoPc/30));
	
	
% 	PoPcSlope=diff(PoPcp,1,2);
% 	PoPcSlope(:,end+1)=PoPcSlope(:,end);
% 	figure
% 	s = surface(Gamma,dA,PoPcp,'cdata',PoPcSlope);           
% 	shading interp
% 	set(s,'edgecolor','interp','edgealpha','interp','facealpha',0,'alphadata',PoPcAlpha);
% 	set(s,'backfacelighting','unlit');
% 	set(s,'MeshStyle','row','LineWidth',1.5);
% 	colormap(jet);
% 	xlabel('Gamma, dyne/cm','Interpreter','none')
% 	ylabel('dA, nm^2','Interpreter','none')
% 	zlabel('log of Po/Pc','Interpreter','none')
% 	set(gca,'XGrid','on')
% 	set(gca,'YGrid','on')
% 	set(gca,'ZGrid','on')
% 	lighting gouraud; 

	figure
	mesh(dE,dA,ApDeltaA','FaceColor','none','EdgeColor','black');
	%mesh(dE,dA,[ApDeltaE;ApDeltaA;ApGamma05]);
	xlabel('dE, kT','Interpreter','none')
	ylabel('dA, nm^2','Interpreter','none')
	%zlabel('DeltaE, kT;  DeltaA, nm^2;  Gamma, dyne/cm','Interpreter','none')
	zlabel('DeltaA, nm^2','Interpreter','none')
	hold on
	[t,hd]=contour3(dE,dA,ApDeltaA',[ExprDeltaA, ExprDeltaA]);
	set(hd,'EdgeColor','black','LineWidth',3)
	hold off


	figure
	mesh(dE/DeltaE,dA/DeltaA,(ApDeltaA')/DeltaA,'FaceColor','none','EdgeColor','black');
	%mesh(dE,dA,[ApDeltaE;ApDeltaA;ApGamma05]);
	xlabel('Relative \sigmaE')
	ylabel('Relative \sigmaA')
	%zlabel('DeltaE, kT;  DeltaA, nm^2;  Gamma, dyne/cm','Interpreter','none')
	zlabel('Relative \DeltaA')
	hold on
	[t,hd]=contour3(dE/DeltaE,dA/DeltaA,(ApDeltaA')/DeltaA,[ExprDeltaA/DeltaA, ExprDeltaA/DeltaA]);
	set(hd,'EdgeColor','black','LineWidth',2)
	hold off

case {'Area', 'AreaEnergy'}	%Activation curves at different energy dispersions and different Areas
	for a=1:AreaSteps	%cycle through areas
		if CalcMode=='AreaEnergy'	%Area and energy changing proportionally, to keep Gamma05 the same
			DeltaE=DeltaAs(a)*Gamma05/4.0474;	%energy to keep the same Gamma05 for the current DeltaA
		end	%Area and energy changing proportionally, to keep Gamma05 the same
		ApDeltaE=[]; ApDeltaA=[];  ApGamma05=[];
		for d=1:EnergySteps	%Cycle throught the increasing values of the standard deviation of energy between channels
			DeltaEs=DeltaE+dEs*dE(d);	%Current matrix of energies of channel opening kT
			for g=1:GammaSteps	%Cycle through the tension steps
				Pos=1./(1+exp(DeltaEs-(1E-21)*Gamma(g)*DeltaAs(a)/kT));	%Matrix of  probabilities to be open at the given value of energy dispersion and tension value for every channel. 1E-21 is conversion factor from (nm^2*dynes/cm) to J
				Po(d,g)=mean(Pos);	%Average (per patch) probability to be open at the given value of energy dispersion and tension value
			end 	%Cycle through the tension steps
		end	%Cycle throught the increasing values of the standard deviation of energy between channels
		
		Pot=Po; Pot(Pot==1)=max(Pot(Pot<1)); Pot(Pot==0)=min(Pot(Pot>0));	%remove values which will give infinity and zeros
		PoPc=Pot./(1-Pot);	%Po/Pc ratio
		PoPct=PoPc; PoPct(PoPct>MaxPoPc)=MaxPoPc; PoPct(PoPct<MinPoPc)=MinPoPc;	%remove values which will give infinity and zeros
		
		%***************** Make a linear fit and extract apparent energy and area
		for  d=1:EnergySteps	%Cycle throught the increasing values of the standard deviation of energy between channels
			PointsInRange=find((PoPc(d,:)>=MinPoPc)&(PoPc(d,:)<=MaxPoPc));	%Select pressure steps fitting into the observable range
			v = polyfit(Gamma(PointsInRange),log(PoPc(d,PointsInRange)),1);	%Make a linear fit and extract parameters - ApDeltaE in kT, ApDeltaA in 1/(kT*dynes/cm)
			ApDeltaA(d)=v(1);
			ApDeltaE(d)=-v(2);
		end	%Cycle throught the increasing values of the standard deviation of energy between channels
		ApGamma05=ApDeltaE./ApDeltaA;
		ApDeltaA=ApDeltaA*kT*(1E21);	%Conversion to nm^2
		
		if PlotInterm==1	%plot intermediate results of calculation
			figure
			hp=surfl(Gamma,dE,Po);
			xlabel('Gamma, dyne/cm','Interpreter','none')
			ylabel('dE, kT','Interpreter','none')
			zlabel('Po','Interpreter','none')
			
			figure
			hp=surfl(Gamma,dE,PoPct);
			xlabel('Gamma, dyne/cm','Interpreter','none')
			ylabel('dE, kT','Interpreter','none')
			zlabel('Po/Pc','Interpreter','none')
			set(gca,'ZScale','log');
			
			figure
			plot(dE,[ApDeltaE;ApDeltaA;ApGamma05]);
		end	%plot intermediate results of calculation
		
		%Find where apparent area decreases 2 times
		dEhalf(a)=interp1(ApDeltaA,dE,DeltaAs(a)/2,'spline');
		
	end	%cycle through areas
	
	
	%colormap('bone')
	figure
	hp=surfl(Gamma,dE,Po);
	%shading interp
	%set(hp,'EdgeColor','k')
	%light('Position',[ -50 -250 3000 ])
	xlabel('Gamma, dyne/cm','Interpreter','none')
	ylabel('dE, kT','Interpreter','none')
	zlabel('Po','Interpreter','none')
	
	%view([20,70])
	
	figure
	hp=surfl(Gamma,dE,PoPct);
	xlabel('Gamma, dyne/cm','Interpreter','none')
	ylabel('dE, kT','Interpreter','none')
	zlabel('Po/Pc','Interpreter','none')
	set(gca,'ZScale','log');
	
	PoPct2=PoPc; PoPct2(PoPct2>MaxPoPc*100)=MaxPoPc*100; PoPct2(PoPct2<MinPoPc/100)=MinPoPc/100;	%remove values which will give infinity and zeros
	%PoPct2=PoPc; PoPct2(PoPct2>MaxPoPc*100)=NaN; PoPct2(PoPct2<MinPoPc/100)=NaN;	%remove values which will give infinity and zeros
	PoPcAlpha=ones(size(PoPc));
	PoPcAlpha(PoPc>1)=0;
	%PoPct2(PoPct2>MaxPoPc*100)=Inf; PoPct2(PoPct2<MinPoPc/100)=0;	%remove values which will give infinity and zeros
	% figure
	% hp=surface(Gamma,dE,PoPct2,'facecolor','texture','cdata',PoPcAlpha,'alphadata',PoPcAlpha);
	% set(hp,'edgecolor','none','facealpha','texture','alphadata',PoPcAlpha,'ALim',[0.1 1]);
	% xlabel('Gamma, dyne/cm','Interpreter','none')
	% ylabel('dE, kT','Interpreter','none')
	% zlabel('Po/Pc','Interpreter','none')
	% set(gca,'ZScale','log');
	% %alpha('direct'); alphamap([.1;0.9])
	% alpha('scaled'); 
	
	PoPcp=log10(PoPct2);
	PoPcAlpha=ones(size(PoPc));
	% PoPcAlpha(PoPc>MaxPoPc*10)=max(0,1-(PoPc(PoPc>MaxPoPc*10)-MaxPoPc*10)/(MaxPoPc*100-MaxPoPc*10));
	% PoPcAlpha(PoPc<MinPoPc/10)=max(0,1-(PoPc(PoPc<MinPoPc/10)-MinPoPc/10)/(MinPoPc/100-MinPoPc/10));
	PoPcAlpha(PoPc>MaxPoPc*30)=max(0,1-(PoPc(PoPc>MaxPoPc*30)-MaxPoPc*30)/(MaxPoPc*100-MaxPoPc*30));
	PoPcAlpha(PoPc<MinPoPc/30)=max(0,1-(PoPc(PoPc<MinPoPc/30)-MinPoPc/30)/(MinPoPc/100-MinPoPc/30));
	%PoPcAlpha(PoPct2==MinPoPc*100)=0;
	
	PoPcSlope=diff(PoPcp,1,2);
	PoPcSlope(:,end+1)=PoPcSlope(:,end);
	figure
	s = surface(Gamma,dE,PoPcp,'cdata',PoPcSlope);           
	shading interp
	%set(s,'edgecolor','black','edgealpha','interp','facealpha',' interp','alphadata',PoPcAlpha);
	set(s,'edgecolor','interp','edgealpha','interp','facealpha',0,'alphadata',PoPcAlpha);
	
	set(s,'backfacelighting','unlit');
	set(s,'MeshStyle','row','LineWidth',1.5);
	%set(gca,'ZTickLabel',[0.0001;0.001;0.01;0.1;1;10;100;1000;10000])
	colormap(jet);
	xlabel('Gamma, dyne/cm','Interpreter','none')
	ylabel('dE, kT','Interpreter','none')
	zlabel('log of Po/Pc','Interpreter','none')
	set(gca,'XGrid','on')
	set(gca,'YGrid','on')
	set(gca,'ZGrid','on')
	% set(gca,'ZScale','log');
	%axis off vis3d; campos([2 13 10]); camlight; 
	lighting gouraud;   
	
	
	if PlotAreaEffect==1;	%Plot results of area change effect
		figure
		plot(dE,[ApDeltaE;ApDeltaA;ApGamma05]);
		xlabel('dE, kT','Interpreter','none')
		ylabel('DeltaE, kT;  DeltaA, nm^2;  Gamma, dyne/cm','Interpreter','none')
		
		% hold on
		% plot(dE,ApDeltaA);
		% plot(dE,ApGamma05);
		figure
		plot(DeltaAs,dEhalf,'r');	%Energy dispersion (kt) necessary to decrease apparent DeltaA 2 times 
		xlabel('DeltaA, nm^2','Interpreter','none')
		ylabel('Energy dispersion (kt) necessary to decrease apparent DeltaA 2 times','Interpreter','none')
		
		figure
		plot(DeltaAs,dEhalf./(DeltaAs*Gamma05/(kT*(1E21))),'g');
		xlabel('DeltaA, nm^2','Interpreter','none')
		ylabel('Energy dispersion (%) necessary to decrease apparent DeltaA 2 times','Interpreter','none')
		
		figure
		plot(DeltaAs,(kT*(1E21))*dEhalf./DeltaAs);
		xlabel('DeltaA, nm^2','Interpreter','none')
		ylabel('Gamma05 dispersion (dyne/cm) necessary to decrease apparent DeltaA 2 times','Interpreter','none')
		
		figure
		plot(DeltaAs,(kT*(1E21))*DeltaAs.^(-1));
		xlabel('DeltaA, nm^2','Interpreter','none')
		ylabel('Tension (dyne/cm) range for e-fold increase in Po/Pc','Interpreter','none')
		
		figure
		plot((kT*(1E21))*DeltaAs.^(-1),(kT*(1E21))*dEhalf./DeltaAs);
		xlabel('Tension (dyne/cm) range for e-fold increase in Po/Pc','Interpreter','none')
		ylabel('Gamma05 dispersion (dyne/cm) necessary to decrease apparent DeltaA 2 times','Interpreter','none')
		
		figure
		hp=plot3(DeltaAs,(kT*(1E21))*DeltaAs.^(-1),(kT*(1E21))*dEhalf./DeltaAs);
		xlabel('DeltaA, nm^2','Interpreter','none')
		ylabel('Tension (dyne/cm) range for e-fold increase in Po/Pc','Interpreter','none')
		zlabel('Gamma05 dispersion (dyne/cm) necessary to decrease apparent DeltaA 2 times','Interpreter','none')
	end	%Plot results of area change effect
end	%Mode of calculation