function [par_val,Function_counts,Iterations,fval]=random_search(par_val,tst_dev,mx_stp,MaxIter,...
	dev0,dev,TolX,TolFun,dif,dir);

%INPUT:
%par_val	- Parameter values set
%tst_dev	- Name of the function for deviation estimation
%mx_stp 	- Maximal evaluation steps number	
%MaxIter	- Maximal iteration steps
%dev0	- parameter deviation change rate
%dev	- Initial Deviation for optimization
%TolX	- Optimization parameter exit tolerance
%TolFun	- Optimization function exit tolerance
%dif	- difference exponent between expanding and shrinking
%dir	- directed <1> or Nondirected <2> search

%OUTPUT:
%par_val 	- optimalo values for parameters
%funcCount 	- Function counts
%iterations - Number of approximation steps;
%fval 	- Final deviation value;

if nargin == 2
	Npoints=length(par_val);	%number of independent variables
	mx_stp=(20*Npoints)^2;	%Maximal evaluation steps number	
	MaxIter=(2*Npoints)^1.5;	%Maximal iteration steps
	dev0=2;	%parameter deviation change rate
	dev=dev0/100;	%Initial Deviation for optimization
	TolX=0.0001;	%Optimization parameter exit tolerance
	TolFun=0.0001;	%Optimization function exit tolerance
	dif=2;	%difference exponent between expanding and shrinking
	dir=1;	%directed <1> or Nondirected <2> search
end
ecount_L=0;   %Function evaluations counter
delta=randn(size(par_val))*dev;	%First parameters deviation
par_val=par_val.*(1+delta);	%Start parameters
delta=randn(size(par_val))*dev;	%First parameters deviation
par_val_t=par_val.*(1+delta);	%First test parameters
[f,ecount_L]=eval([tst_dev '(par_val,ecount_L)']);  %Start deviation

%block for initial data save
cont=1;	%flag to continue search
sdev(1)=2*f;	%Successful steps deviation matrix
sdev(2)=f;	%Successful steps deviation matrix
ntest=ceil(length(par_val)^.5)+1;	%Maximal number of test from one point with the same deviation
ctest=1;	%Number of test at the current point
dec1=1;	%Flag of first step decreasing

while cont>0
	[d,ecount_L]=eval([tst_dev '(par_val_t,ecount_L)']);  %Evaluate deviation for proposed parameters values
	if d<sdev(end)	%successful step
		ctest=1;	%Resetting test number
		sdev(end+1)=d;	%Adding new step deviation
		par_val=par_val_t;	%Accepting new parameters
		dev=dev*(dev0^(1/dif));	%Increasing parameter deviation
		dec1=0;	%Flag of first step decreasing
		if dir ==1	%Directed search
			delta=delta*(dev0^(1/dif));
		else	%Undirected search
			delta=randn(size(par_val))*dev;
		end
		SndN(1);
		
		%*** test plotting block. Remove after debugging
		if floor(length(sdev)/50)==length(sdev)/50
		end
	else	%unsuccessful step
		if ctest<ntest	%Testing directions
			if dir ==1&ctest==1&dec1==1	%Directed search, 2n attempt, after search range shrink
				delta=-1*delta;
			else	%Undirected search
				delta=randn(size(par_val))*dev;
			end
			ctest=ctest+1;
		else	%Decreasing step size
			ctest=1;	%Resetting test number
			dev=dev/(dev0^dif);
			dec1=1;
			if dir ==1	%Directed search
				delta=-1*delta/(dev0^dif);
			else	%Undirected search
				delta=randn(size(par_val))*dev;
			end
		end
	end
	par_val_t=par_val.*(1+delta);
	m=mean(sdev(max(1,end-2*ntest):end));
	if m==0
		d_fun=0;
	else
		d_fun=abs(std(sdev(max(1,end-2*ntest):end))/m);%Average criterion function deviation in success steps
	end
	cont=min([(mx_stp-ecount_L),sdev(end),(d_fun-TolFun)]);	%Decides to continue search(>0) or not(<=0)
end
Function_counts=ecount_L; %! Function counts
Iterations=length(sdev);  %!Number of approximation steps;
fval=sdev(end);  %!Final deviation value;


