function [par_val,Function_counts,Iterations,fval]=random_search_combfit(par_val,tst_dev,mx_stp,MaxIter,...
	dev0,dev,TolX,TolFun,dif,dir,msg,tries,expadd);

%INPUT:
%par_val	- Parameter values set
%tst_dev	- Name of the function for deviation estimation
%mx_stp 	- Maximal evaluation steps number	
%MaxIter	- Maximal iteration steps
%dev0	- parameter deviation change rate
%dev	- Initial Deviation for optimization
%TolX	- Optimization parameter exit tolerance
%TolFun	- Optimization function exit tolerance
%dif	- difference exponent between expanding and shrinking
%dir	- directed <1>, Nondirected <2>, Persistive <3> (use all possible attempts) search
%msg	- messaging frequency - no messages <0>, message on screen every <#> sucessfull steps
%tries	- 	%Maximal number of test from one point with the same deviation
%expadd	- mod of the parameter change: exponential <1> (for 0 to Inf parameters) or <2> additive (for -Inf to Inf parameters)


%OUTPUT:
%par_val 	- optimalo values for parameters
%funcCount 	- Function counts
%iterations - Number of approximation steps;
%fval 	- Final deviation value;

if nargin == 2
	Npoints=length(par_val);	%number of independent variables
	mx_stp=(20*Npoints)^2;	%Maximal evaluation steps number	
	MaxIter=round((20*Npoints)^1.5);	%Maximal iteration steps
	dev0=2;	%parameter deviation change rate
	dev=dev0/100;	%Initial Deviation for optimization
	TolX=0.0001;	%Optimization parameter exit tolerance
	TolFun=0.0001;	%Optimization function exit tolerance
	dif=2;	%difference exponent between expanding and shrinking
	dir=1;	%directed <1>, Nondirected <2>, Persistive <3> (use all possible attempts) search
	msg=10;	%messaging frequency - no messages <0>, message on screen every <#> sucessfull steps
	tries=ceil(length(par_val)^.5)+1;	%Maximal number of test from one point with the same deviation
	expadd=1;	%mod of the parameter change: exponential <1> (for 0 to Inf parameters) or additive (for -Inf to Inf parameters)

end
ecount_L=0;   %Function evaluations counter
%Change parameters by delta
% delta=randn(size(par_val))*dev;	%First parameters deviation
% switch 	expadd	%mod of the parameter change
% case 1	%exponential <1> (for 0 to Inf parameters)
% 	par_val=par_val.^(1+delta);	%Start parameters
% case 2	%additive (for -Inf to Inf parameters)
% 	par_scale=abs(par_val); par_scale(par_scale==0)=TolX;
% 	par_val=par_val+par_scale.*delta;	%Start parameters
% end
delta=randn(size(par_val))*dev;	%First parameters deviation
switch 	expadd	%mod of the parameter change
case 1	%exponential <1> (for 0 to Inf parameters)
	par_val_t=par_val.^(1+delta);	%First test parameters
case 2	%additive (for -Inf to Inf parameters)
	par_scale=abs(par_val); par_scale(par_scale==0)=TolX;
	par_val_t=par_val+par_scale.*delta;	%First test parameters
end

[f,ecount_L]=eval([tst_dev '(par_val,ecount_L)']);  %Start deviation

%block for initial data save
cont=1;	%flag to continue search
sdev=2*f;	%Successful steps deviation matrix
sdev(2)=f;	%Successful steps deviation matrix
ctest=1;	%Number of test at the current point
dec1=1;	%Flag of first step decreasing
par_val_tList={};	%list of multiple attempts' parameters for persistive method
deltaList={};	%list of multiple attempts' deltas for persistive method
dList=[];	%List of multiple attempts' deviations for persistive method
ecount_L=0;

while cont>0
	[d,ecount_L]=eval([tst_dev '(par_val_t,ecount_L)']);  %Evaluate deviation for proposed parameters values
	if dir==3	%persistive search
		dList(end+1)=d;
		par_val_tList{end+1}=par_val_t;
		deltaList{end+1}=delta;
	end
	
	if (d<sdev(end)&dir~=3)|(ctest==tries&dir==3&min(dList)<sdev(end))	%successful step or the last try in persistive search step
		ctest=1;	%Resetting test number
		dev=dev*(dev0^(1/dif));	%Increasing parameter deviation
		dec1=0;	%Flag of first step decreasing
		if dir ==1	%Directed search
			delta=delta*(dev0^(1/dif));
			sdev(end+1)=d;	%Adding new step deviation
			par_val=par_val_t;	%Accepting new parameters
		elseif dir==2	%Undirected search
			delta=randn(size(par_val))*dev;
			sdev(end+1)=d;	%Adding new step deviation
			par_val=par_val_t;	%Accepting new parameters
		elseif dir==3	%Persistive search
			[sdev(end+1),minDev]=min(dList);	%Adding new step deviation
			dList=[];
			delta=deltaList{minDev};	%Accepting new parameters
			deltaList={};
			delta=delta*(dev0^(1/dif));
			par_val=par_val_tList{minDev};	%Accepting new parameters
			par_val_tList={};
		end	%Directed search
		SndN(1);
		if msg >0	%Messaging on screen
			%*** test plotting block. Remove after debugging
			if floor(length(sdev)/msg)==length(sdev)/msg
				disp(['Evaluation #: ',num2str(ecount_L),'      Iteration #: ',num2str(length(sdev)),'      Deviation: ',num2str(sdev(end))])
			end
		end
	else	%unsuccessful step
		if ctest<tries	%Testing directions
			if dir ==1	%Directed search,
				if ctest==1&dec1==1	% 2n attempt, after search range shrink
					delta=-1*delta;
				else
					delta=randn(size(par_val))*dev;
				end
			elseif dir==2	%Undirected search
				delta=randn(size(par_val))*dev;
			elseif dir ==3	%persistive search
				if ctest==1&dec1==1	% 2n attempt, after search range shrink
					delta=-1*delta;
				else
					delta=randn(size(par_val))*dev;
				end
			end
			ctest=ctest+1;
		else	%Decreasing step size
			ctest=1;	%Resetting test number
			dev=dev/(dev0^dif);
			dec1=1;
			if dir ==1	%Directed search
				delta=-1*delta/(dev0^dif);
			elseif dir==2	%Undirected search
				delta=randn(size(par_val))*dev;
			elseif dir ==3	%persistive search
				delta=-1*delta/(dev0^dif);
			end
		end
	end
	
	%Change parameters by delta
	switch 	expadd	%mode of the parameter change
	case 1	%exponential <1> (for 0 to Inf parameters)
		%par_val_t=par_val.^(1+delta);
		par_val_t=par_val.*(dev0.^delta);
	case 2	%additive (for -Inf to Inf parameters)
		par_scale=abs(par_val); par_scale(par_scale==0)=TolX;
		par_val_t=par_val+par_scale.*delta;
	end

	m=mean(sdev(max(1,end-2*tries):end));
	if m==0
		d_fun=0;
	else
		d_fun=abs(std(sdev(max(1,end-2*tries):end))/m);%Average criterion function deviation in success steps
	end
	%cont=min([(mx_stp-ecount_L),sdev(end),(d_fun-TolFun)]);	%Decides to continue search(>0) or not(<=0)
	cont=min([(mx_stp-ecount_L),(MaxIter-length(sdev)),sdev(end),(d_fun-TolFun)]);	%Decides to continue search(>0) or not(<=0)
end
Function_counts=ecount_L; %! Function counts
Iterations=length(sdev);  %!Number of approximation steps;
fval=sdev(end);  %!Final deviation value;

