%rebinhst - function, rebinning histogram into specified bins
function [HstR,BinsXn,MaxsXn,BinsYn,MaxsYn]=rebinhst(Hst,RebTypeX,MinX,StepX,MaxX,BinsX,NormX,...
    NormRelX,NormRelSubX,RebTypeY,MinY,StepY,MaxY,BinsY,NormY,NormRelY,NormRelSubY,NormZN,InterpLevZ,...
	InterpType,h_pdfX,h_pdfY,h_pdfZ,TimeRng,TimeRngType,TimeRngProf)
%Outputs:
%HstR -	Rebinned histogram file
%BinsXn -	New X axes bins
%BinsYn -	New Y axes bins
%MaxsXn -	Maximums vector for the new X axis bins.
%MaxsYn -	Maximums vector for the new Y axis bins.

%Inputs:
%Hst - histogram data file
%RebTypeX -	Mode for X axis rebinning: none <1*>, Auto extremum select <5>
%Defined number of steps <2>, new bins width <3>, bins vector <4>, just averaging to the same bins <6>
%MinX -	Minimal X value from edit box
%StepX -	Number of new bins for X axis, averaging length, or new bins vector, depending on RebTypeX
%MaxX -	Maximal X value from edit box
%BinsX -	Old bins vector for X axis
%NormX -	Normalize <1> X values or not <0*> relative to NormRelX value
%NormRelX -	Value for X normalization
%RebTypeY -	Mode for Y axis rebinning: none <1*>, Auto extremum select <2>,
%Defined number of steps <3>, bins vector <4>, just averaging to the same bins <5>
%StepY -	Number of new bins for Y axis, averaging length, or new bins vector, depending on RebTypeY
%BinsY -	Old bins vector for Y axis
%NormZN -	Mode for Z axis values normalization:'Z Absolute' <1*> - no normalization,
%'Z/All pnts' <2> - relative to all points in current X bin,'Z/X pnts' <3>,'Z/Y pnts' <4>
%InterpLevZ -	Treshold level for Z values interpolation, relative to mean value for the axis bin
%InterpType -	Interpolation type between 2 over-treshold lines: 'None' <1*>,'Linear' <2>,'Exponential <3>, 'Enfrcd Linr' <4>, 'Enfrcd Expntl' <5>
%h_pdfX,h_pdfY,h_pdfZ -	%Option to treat X, Y or Z as a Probability Density Function (after rebinning divide on bin's width to maintain probability level).

BinsXn=[]; BinsYn=[];
MaxsXn=[]; MaxsYn=[];
Hst(isnan(Hst))=min(Hst(:));	%protection for NaN entries
HstR=Hst;

if NormX
    if (NormRelSubX~=0);	%Substracting NormRelSubX from X axis values 
        BinsX=BinsX-NormRelSubX;
        MinX=MinX-NormRelSubX;
        MaxX=MaxX-NormRelSubX;
    end
    if (NormRelX~=0)%&(NormRelX~=1);	%Normalizing X axis values relative to NormRelX
        NormRelX=NormRelX-NormRelSubX;
        BinsX=BinsX/NormRelX;
        MinX=MinX/NormRelX;
        MaxX=MaxX/NormRelX;
    end
end
if NormY
    if (NormRelSubY~=0);	%Substracting NormRelSubY from Y axis values 
        NormRelY=NormRelY-NormRelSubY;
        BinsY=BinsY-NormRelSubY;
        MinY=MinY-NormRelSubY;
        MaxY=MaxY-NormRelSubY;
    end
    if (NormRelY~=0)%&(NormRelY~=1);	%Normalizing Y axis values relative to NormRelY
        BinsY=BinsY/NormRelY;
        MinY=MinY/NormRelY;
        MaxY=MaxY/NormRelY;
    end
end

ZerX='NX';
%***	Rebinning X axis (current)
switch RebTypeX
case 1
    BinsXn=BinsX;
case 2	%Defined number of steps
    %   BinsXn=max(MinX,BinsX(1)):(BinsX(end)-BinsX(1))/StepX:min(MaxX,BinsX(end));
    BinsXn=MinX:(MaxX-MinX)/StepX:MaxX;
    HstR=distrhst(HstR,BinsX,BinsXn,1,InterpLevZ,InterpType);
case 3	%Defined bin width
    %BinsXn=max(MinX,BinsX(1)):StepX:min(MaxX,BinsX(end));
    BinsXn=MinX:StepX:MaxX;
    HstR=distrhst(HstR,BinsX,BinsXn,1,InterpLevZ,InterpType);
case 4	%bins vector
    BinsXn=StepX;
    HstR=distrhst(HstR,BinsX,BinsXn,1,InterpLevZ,InterpType);
case 5	%Auto extremum select
    HstX=sum(HstR,2);	%Total histogram summarized along rows.
    HstX=averhst(HstX,StepX);	%Averaging histogram among +-StepX neighbors
    ExtrFindMethod='MinMax';    %Method of extremums search
    [BinsXn,MaxsXn] =findextrhst(HstX,StepX,BinsX,ExtrFindMethod);	%Finding extremums of histogram,
    %and assigning minimums and boundaries as bins
    HstR=distrhst(HstR,BinsX,BinsXn,1,InterpLevZ,InterpType);
case 6	%just averaging to the same bins 
    HstRn=zeros(size(HstR));
    BinsXn=BinsX;
    for i=1:size(HstR,2)	%cycle by Y
        HstRn(:,i)=[averhst(HstR(:,i),StepX)]';	%Avereging histogram among +-StepX neighbors
    end
    HstR=HstRn;
case 7  %,'Zeroing'
    ZerX='ZX';
    BinsXn=BinsX;
case 8	%Rebinning between the Defined number of maximums
    HstX=sum(HstR,2);	%Total histogram summarized along rows.
    ExtrFindMethod='NumMax';    %Method of extremums search
    [BinsXn,MaxsXn] =findextrhst(HstX,StepX,BinsX,ExtrFindMethod);	%Finding extremums of histogram,
    %and assigning minimums and boundaries as bins
    HstR=distrhst(HstR,BinsX,BinsXn,1,InterpLevZ,InterpType);
case 9  %'log P Crossection' - makes boundary at the point of crossection
    HstX=sum(HstR,2);	%Total histogram summarized along rows.
    ExtrFindMethod='CrosLev';    %Method of extremums search
    [BinsXn,MaxsXn] =findextrhst(HstX,StepX,BinsX,ExtrFindMethod);	%Finding extremums of histogram,
    %and assigning minimums and boundaries as bins
    HstR=distrhst(HstR,BinsX,BinsXn,1,InterpLevZ,InterpType);
end


ZerY='NY';
%***	Rebinning Y axis (pressure)
switch RebTypeY
case 1
    BinsYn=BinsY;
case 2	%Defined number of steps
    %   BinsYn=max(MinY,BinsY(1)):(BinsY(end)-BinsY(1))/StepY:min(MaxY,BinsY(end));
    BinsYn=MinY:(MaxY-MinY)/StepY:MaxY;
    HstR=distrhst(HstR,BinsY,BinsYn,2,InterpLevZ,InterpType);
case 3	%Defined bin width
    %BinsYn=max(MinY,BinsY(1)):StepY:min(MaxY,BinsY(end));
    BinsYn=MinY:StepY:MaxY;
    HstR=distrhst(HstR,BinsY,BinsYn,2,InterpLevZ,InterpType);
case 4	%bins vector
    BinsYn=StepY;
    HstR=distrhst(HstR,BinsY,BinsYn,2,InterpLevZ,InterpType);
case 5	%Auto extremum select
    HstY=sum(HstR,1);	%Total histogram summarized along rows.
    HstY=averhst(HstY,StepY);	%Avereging histogram among +-StepY neighbors
    ExtrFindMethod='MinMax';    %Method of extremums search
    [BinsYn,MaxsYn] =findextrhst(HstY,StepY,BinsY,ExtrFindMethod);	%Finding extremums of histogram,
    %and assigning minimums and boundaries as bins
    HstR=distrhst(HstR,BinsY,BinsYn,2,InterpLevZ,InterpType);
case 6	%just averaging to the same bins 
    HstRn=zeros(size(HstR));
    BinsYn=BinsY;
    for i=1:size(HstR,1)	%cycle by X
        HstRn(i,:)=averhst(HstR(i,:),StepY);	%Avereging histogram among +-StepY neighbors
    end
    HstR=HstRn;
case 7  %,'Zeroing'
    ZerY='ZY';
    BinsYn=BinsY;
case 8	%Rebinning between the Defined number of maximums
    HstY=sum(HstR,1);	%Total histogram summarized along rows.
    ExtrFindMethod='NumMax';    %Method of extremums search
    [BinsYn,MaxsYn] =findextrhst(HstY,StepY,BinsY,ExtrFindMethod);	%Finding extremums of histogram,
    %and assigning minimums and boundaries as bins
    HstR=distrhst(HstR,BinsY,BinsYn,2,InterpLevZ,InterpType);
case 9  %'log P Crossection' - makes boundary at the point of crossection
    HstY=sum(HstR,1);	%Total histogram summarized along rows.
    ExtrFindMethod='CrosLev';    %Method of extremums search
    [BinsYn,MaxsYn] =findextrhst(HstY,StepY,BinsY,ExtrFindMethod);	%Finding extremums of histogram,
    %and assigning minimums and boundaries as bins
    HstR=distrhst(HstR,BinsY,BinsYn,2,InterpLevZ,InterpType);
end

if length(MaxsXn)==0
    for i=1:(length(BinsXn)-1)
        MaxsXn(i)=(BinsXn(i)+BinsXn(i+1))/2;
    end
end
if length(MaxsYn)==0
    for i=1:(length(BinsYn)-1)
        MaxsYn(i)=(BinsYn(i)+BinsYn(i+1))/2;
    end
end


if (RebTypeX==4|RebTypeX==5)&(h_pdfX==1)	%Bins vector. Ajust points number according to bins length's
    s=(BinsXn(end)-BinsXn(1))/(length(BinsXn)-1);
    for i=1:(length(BinsXn)-1)
        d=(BinsXn(i+1)-BinsXn(i))/s;
        HstR(i,:)=HstR(i,:)/d;
    end
end

if (RebTypeY==4|RebTypeY==5)&(h_pdfY==1)	%Bins vector. Ajust points number according to bins length's
    s=(BinsYn(end)-BinsYn(1))/(length(BinsYn)-1);
    for i=1:(length(BinsYn)-1)
        d=(BinsYn(i+1)-BinsYn(i))/s;
        HstR(:,i)=HstR(:,i)/d;
    end
end

%ZerZ='NZ';
ZerTot=[ZerX,ZerY];
switch ZerTot
case 'NXNY'
case 'NXZY'
    MinYn=min(find(BinsYn>=MinY));
    MaxYn=max(find(BinsYn<=MaxY))-1;
    HstR(:,MinYn:MaxYn)=0;
case 'ZXNY'
    MinXn=min(find(BinsXn>=MinX));
    MaxXn=max(find(BinsXn<=MaxX))-1;
    HstR(MinXn:MaxXn,:)=0;
case 'ZXZY'
    MinYn=min(find(BinsYn>=MinY));
    MaxYn=max(find(BinsYn<=MaxY))-1;
    MinXn=min(find(BinsXn>=MinX));
    MaxXn=max(find(BinsXn<=MaxX))-1;
    HstR(MinXn:MaxXn,MinYn:MaxYn)=0;
end


%***	Normalizing Z values
switch NormZN	%Mode for Z axis values normalization
case 1	%'Z Absolute' <1*> - no normalization
case 2	%'Z/All pnts'
    HstR=HstR/sum(sum(HstR));
case 3	%'Z/X pnts' 
    HstD=sum(HstR,2); %1-dimensional sum histogram
	if InterpType==1	%'None' interpolation
		InterpLevZ=min(HstD(:))-1;
	elseif InterpType==8	%'Zeroing' interpolation
		InterpLevZ=10^InterpLevZ;
	else
		InterpLevZ=InterpLevZ*sum(sum(HstR))/length(HstD);	%Interpolation treshold converted into points number
	end
    HstDBelowN=find(HstD<InterpLevZ);
    HstDAboveN=find(HstD>=InterpLevZ);
    for i=1:length(HstD)	%Normalizing lines which are above treshold
        if (HstD(i)>=InterpLevZ)&(sum(HstR(i,:))~=0)
            HstR(i,:)=HstR(i,:)/sum(HstR(i,:));
        end
    end
    if InterpType==1	%there is no interpolation
	elseif InterpType==8	%'Zeroing' interpolation - wrong rows are zeroed
        HstR(HstDBelowN,:)=0;
    else %There is some kind of interpolation
        for i=1:length(HstDBelowN)
            MinN=find(HstDAboveN<HstDBelowN(i));
            MaxN=find(HstDAboveN>HstDBelowN(i));
            if length(MinN)>0;	%there is at least 1 normal row before
                MinN=max(MinN);
                if length(MaxN)>0;	%there is at least 1 normal row after
                    MaxN=min(MaxN);	%there are two normal rows - before and after
                    switch InterpType
                    case 2	%Linear
                        HstR(HstDBelowN(i),:)=HstR(MinN,:)+(HstR(MaxN,:)-HstR(MinN,:))*...
                            (HstDBelowN(i)-MinN)/(MaxN-MinN); 
                    case 3	%Exponential
                        HstR(HstDBelowN(i),:)=exp(log(HstR(MinN,:))-(log(HstR(MaxN,:))-...
                            log(HstR(MinN,:)))*(HstDBelowN(i)-MinN)/(MaxN-MinN)); 
                    end
                else
                    HstR(HstDBelowN(i),:)=HstR(MinN,:);	%there is  normal row only before
                end
            else
                if length(MaxN)>0;	%there is at least 1 normal row after
                    MaxN=min(MaxN);
                    HstR(HstDBelowN(i),:)=HstR(MaxN,:);	%there is  normal row only after
                else
                    HstR(HstDBelowN(i),:)=0;	%There is no normal rows
                end
            end
        end
    end
case 4	%'Z/Y pnts'
    HstD=sum(HstR,1); %1-dimensional sum histogram
	if InterpType==1	%'None' interpolation
		InterpLevZ=min(HstD(:))-1;
	elseif InterpType==8	%'Zeroing' interpolation
		InterpLevZ=10^InterpLevZ;
	else
		InterpLevZ=InterpLevZ*sum(sum(HstR))/length(HstD);	%Interpolation treshold converted into points number
	end
    HstDBelowN=find(HstD<InterpLevZ);
    HstDAboveN=find(HstD>=InterpLevZ);
    for i=1:length(HstD)	%Normalizing lines which are above treshold
        if (HstD(i)>=InterpLevZ)&(sum(HstR(:,i))~=0)
            HstR(:,i)=HstR(:,i)/sum(HstR(:,i));
        end
    end
    if InterpType==1	%there is no interpolation
	elseif InterpType==8	%'Zeroing' interpolation - wrong rows are zeroed
        HstR(:,HstDBelowN)=0;
    else %There is some kind of interpolation
        for i=1:length(HstDBelowN)
            MinN=find(HstDAboveN<HstDBelowN(i));
            MaxN=find(HstDAboveN>HstDBelowN(i));
            if length(MinN)>0;	%there is at least 1 normal row before
                MinN=max(MinN);
                if length(MaxN)>0;	%there is at least 1 normal line after
                    MaxN=min(MaxN);	%there are two normal line - before and after
                    switch InterpType
                    case 2	%Linear
                        HstR(:,HstDBelowN(i))=HstR(:,HstDAboveN(MinN))+(HstR(:,MaxN)-HstR(:,HstDAboveN(MinN)))*...
                            (HstDBelowN(i)-HstDAboveN(MinN))/(HstDAboveN(MaxN)-HstDAboveN(MinN)); 
                    case 3	%Exponential
                        HstR(:,HstDBelowN(i))=exp(log(HstR(:,HstDAboveN(MinN)))+(log(HstR(:,HstDAboveN(MaxN)))-log(HstR(:,HstDAboveN(MinN))))*...
                            (HstDBelowN(i)-HstDAboveN(MinN))/(HstDAboveN(MaxN)-HstDAboveN(MinN))); 
                    end
                else
                    HstR(:,HstDBelowN(i))=HstR(:,HstDAboveN(MinN));	%there is  normal line only before
                end
            else
                if length(MaxN)>0;	%there is at least 1 normal line after
                    MaxN=min(MaxN);
                    HstR(:,HstDBelowN(i))=HstR(:,HstDAboveN(MaxN));	%there is  normal line only after
                else
                    HstR(:,HstDBelowN(i))=0;	%There is no normal lines
                end
            end
        end
    end
    %case 7  %,'Zeroing'
    %ZerZ='ZZ';
case 5	%'Z/(Bin area)'
    for i=1:size(HstR,1)
        for j=1:size(HstR,2)
            HstR(i,j)=HstR(i,j)/((BinsXn(i+1)-BinsXn(i))*(BinsYn(i+1)-BinsYn(i)));	%Divides each bin value to the area of this bin - this is to convert histogram to the probability density function for the unequel bins 
        end
    end
case 6  %'Z/(XbinZ)'
    NormBin=max(find(BinsXn<=TimeRng)); %Normalization bin number - by this bin the whole row (or column) will be divided.
    HstD=HstR(NormBin,:); %1-dimensional column (or row) of normalization bins
	if InterpType==1	%'None' interpolation
		InterpLevZ=min(HstD(:))-1;
	elseif InterpType==8	%'Zeroing' interpolation
		InterpLevZ=10^InterpLevZ;
	else
		InterpLevZ=InterpLevZ*sum(sum(HstR))/length(HstD);	%Interpolation treshold converted into points number
	end
    HstDBelowN=find(HstD<InterpLevZ);
    HstDAboveN=find(HstD>=InterpLevZ);
    for i=HstDAboveN	%Normalizing lines which are above treshold
        HstR(:,i)=HstR(:,i)/HstD(i);
    end
    if InterpType==1	%there is no interpolation
	elseif InterpType==8	%'Zeroing' interpolation - wrong rows are zeroed
        HstR(:,HstDBelowN)=0;
    else %There is some kind of interpolation
        for i=1:length(HstDBelowN)  %Cycle through bad bins
            MinN=find(HstDAboveN<HstDBelowN(i));
            MaxN=find(HstDAboveN>HstDBelowN(i));
            if length(MinN)>0;	%there is at least 1 normal row before
                MinN=max(MinN);
                if length(MaxN)>0;	%there is at least 1 normal line after
                    MaxN=min(MaxN);	%there are two normal line - before and after
                    switch InterpType
                    case 2	%Linear
                        HstR(NormBin,HstDBelowN(i))=HstR(NormBin,HstDAboveN(MinN))+(HstR(NormBin,MaxN)-HstR(NormBin,HstDAboveN(MinN)))*...
                            (HstDBelowN(i)-HstDAboveN(MinN))/(HstDAboveN(MaxN)-HstDAboveN(MinN)); 
                    case 3	%Exponential
                        HstR(NormBin,HstDBelowN(i))=exp(log(HstR(NormBin,HstDAboveN(MinN)))+(log(HstR(NormBin,HstDAboveN(MaxN)))-log(HstR(NormBin,HstDAboveN(MinN))))*...
                            (HstDBelowN(i)-HstDAboveN(MinN))/(HstDAboveN(MaxN)-HstDAboveN(MinN))); 
                    end %switch InterpType
                else	%there is not at least 1 normal line after
                    HstR(NormBin,HstDBelowN(i))=HstR(NormBin,HstDAboveN(MinN));	%there is  normal line only before
                end	%there is at least 1 normal line after
            else    %there is not at least 1 normal row before
                if length(MaxN)>0;	%there is at least 1 normal line after
                    MaxN=min(MaxN);
                    HstR(NormBin,HstDBelowN(i))=HstR(NormBin,HstDAboveN(MaxN));	%there is  normal line only after
                else
                    HstR(NormBin,HstDBelowN(i))=0;	%There is no normal lines
                end	%there is at least 1 normal line after
            end %there is at least 1 normal row before   
        end  %Cycle through bad bins
    end %There is some kind of interpolation
case 7  %'Z/(YbinZ)'
    NormBin=max(find(BinsXn<=TimeRng)); %Normalization bin number - by this bin the whole row (or column) will be divided.
    HstD=HstR(:,NormBin); %1-dimensional column (or row) of normalization bins
	if InterpType==1	%'None' interpolation
		InterpLevZ=min(HstD(:))-1;
	elseif InterpType==8	%'Zeroing' interpolation
		InterpLevZ=10^InterpLevZ;
	else
		InterpLevZ=InterpLevZ*sum(sum(HstR))/length(HstD);	%Interpolation treshold converted into points number
	end
    HstDBelowN=find(HstD<InterpLevZ);
    HstDAboveN=find(HstD>=InterpLevZ);
    for i=HstDAboveN	%Normalizing lines which are above treshold
        HstR(i,:)=HstR(i,:)/HstD(i);
    end
    if InterpType==1	%there is no interpolation
	elseif InterpType==8	%'Zeroing' interpolation - wrong rows are zeroed
        HstR(HstDBelowN,:)=0;
    else %There is some kind of interpolation
        for i=1:length(HstDBelowN)  %Cycle through bad bins
            MinN=find(HstDAboveN<HstDBelowN(i));
            MaxN=find(HstDAboveN>HstDBelowN(i));
            if length(MinN)>0;	%there is at least 1 normal row before
                MinN=max(MinN);
                if length(MaxN)>0;	%there is at least 1 normal line after
                    MaxN=min(MaxN);	%there are two normal line - before and after
                    switch InterpType
                    case 2	%Linear
                        HstR(HstDBelowN(i),NormBin)=HstR(HstDAboveN(MinN),NormBin)+(HstR(MaxN,NormBin)-HstR(HstDAboveN(MinN),NormBin))*...
                            (HstDBelowN(i)-HstDAboveN(MinN))/(HstDAboveN(MaxN)-HstDAboveN(MinN)); 
                    case 3	%Exponential
                        HstR(HstDBelowN(i),NormBin)=exp(log(HstR(HstDAboveN(MinN),NormBin))+(log(HstR(HstDAboveN(MaxN),NormBin))-log(HstR(HstDAboveN(MinN),NormBin)))*...
                            (HstDBelowN(i)-HstDAboveN(MinN))/(HstDAboveN(MaxN)-HstDAboveN(MinN))); 
                    end %switch InterpType
                else	%there is not at least 1 normal line after
                    HstR(HstDBelowN(i),NormBin)=HstR(HstDAboveN(MinN),NormBin);	%there is  normal line only before
                end	%there is at least 1 normal line after
            else    %there is not at least 1 normal row before
                if length(MaxN)>0;	%there is at least 1 normal line after
                    MaxN=min(MaxN);
                    HstR(HstDBelowN(i),NormBin)=HstR(HstDAboveN(MaxN),NormBin);	%there is  normal line only after
                else
                    HstR(HstDBelowN(i),NormBin)=0;	%There is no normal lines
                end	%there is at least 1 normal line after
            end %there is at least 1 normal row before   
        end  %Cycle through bad bins
    end %There is some kind of interpolation
case 8  %'Z dA'
	kTnm2=4.047*TimeRng/293; %Normalization bin number - by this bin the whole row (or column) will be divided.
	BinsYd=diff(BinsYn);	%width vector of pressure steps
	BinsYn=(BinsYn(1:(end-1))+BinsYn(2:end))/2;	%Medians of new pressure bins
	if InterpType==1	%'None' interpolation
		InterpLevZ=min(HstD(:))-1;
	elseif InterpType==8	%'Zeroing' interpolation
		InterpLevZ=10^InterpLevZ;
	else
		InterpLevZ=InterpLevZ*sum(sum(HstR))/(size(HstR,1)*size(HstR,2));	%Interpolation treshold converted into points number
	end
	HstDBelowN=find(HstR<InterpLevZ);
	HstDAboveN=find(HstR>=InterpLevZ);
	HstR(HstDBelowN)=0;	%assign zero values for all the bins below treshold
	HstRn=zeros(size(HstR));	%new output histogram
	for i=1:(size(HstR,2)-1)	%Moving along pressure axis
		for j=1:size(HstR,1)	%Moving along current axis
			if (HstR(j,i) > 0)&(HstR(j,(i+1)) > 0)	%Calculating bins which are above treshold
				HstRn(j,i)=kTnm2*log(HstR(j,(i+1))/HstR(j,i))/BinsYd(i);	%dA - it was Multiplaed on coefficient to convert to nm2,log of ratio of 2 bins divided by tension step length
			else
			end	%Calculating bins which are above treshold
		end	%Moving along current axis
	end	%Moving along pressure axis
	HstR=HstRn(:,(1:(end-1)));	%the last bin can't be calculated.
	
case 9  %'Z dE'
	kTnm2=4.047*TimeRng/293; %Normalization bin number - by this bin the whole row (or column) will be divided.
	BinsYd=diff(BinsYn);	%width vector of pressure steps
	BinsYn=(BinsYn(1:(end-1))+BinsYn(2:end))/2;	%Medians of new pressure bins
	if InterpType==1	%'None' interpolation
		InterpLevZ=min(HstD(:))-1;
	elseif InterpType==8	%'Zeroing' interpolation
		InterpLevZ=10^InterpLevZ;
	else
		InterpLevZ=InterpLevZ*sum(sum(HstR))/(size(HstR,1)*size(HstR,2));	%Interpolation treshold converted into points number
	end
	HstDBelowN=find(HstR<InterpLevZ);
	HstDAboveN=find(HstR>=InterpLevZ);
	HstR(HstDBelowN)=0;	%assign zero values for all the bins below treshold
	HstRn=zeros(size(HstR));	%new output histogram
	for i=1:(size(HstR,2)-1)	%Moving along pressure axis
		for j=1:size(HstR,1)	%Moving along current axis
			if (HstR(j,i) > 0)&(HstR(j,(i+1)) > 0)	%Calculating bins which are above treshold
				HstRn(j,i)=log(HstR(j,(i+1))/HstR(j,i))/BinsYd(i);	%dA divided by kT
				HstRn(j,i)=HstRn(j,i)*BinsYn(i)-(log(HstR(j,(i+1))*HstR(j,i))/2);	%dE=dA*Gamma/kT-dGaverage
			else
			end	%Calculating bins which are above treshold
		end	%Moving along current axis
	end	%Moving along pressure axis
	HstR=HstRn(:,(1:(end-1)));	%the last bin can't be calculated.
	
case 10  %'Z Gamma'
	kTnm2=4.047*TimeRng/293; %Normalization bin number - by this bin the whole row (or column) will be divided.
	BinsYd=diff(BinsYn);	%width vector of pressure steps
	BinsYn=(BinsYn(1:(end-1))+BinsYn(2:end))/2;	%Medians of new pressure bins
	if InterpType==1	%'None' interpolation
	elseif InterpType==8	%'Zeroing' interpolation
		InterpLevZ=10^InterpLevZ;
	else
		InterpLevZ=InterpLevZ*sum(sum(HstR))/(size(HstR,1)*size(HstR,2));	%Interpolation treshold converted into points number
	end
	HstDBelowN=find(HstR<InterpLevZ);
	HstDAboveN=find(HstR>=InterpLevZ);
	HstR(HstDBelowN)=0;	%assign zero values for all the bins below treshold
	HstRn=zeros(size(HstR));	%new output histogram
	for i=1:(size(HstR,2)-1)	%Moving along pressure axis
		for j=1:size(HstR,1)	%Moving along current axis
			if (HstR(j,i) > 0)&(HstR(j,(i+1)) > 0)	%Calculating bins which are above treshold
				HstRn(j,i)=log(HstR(j,(i+1))/HstR(j,i))/BinsYd(i);	%dA divided by kT
				if HstRn(j,i) ~= 0
					HstRn(j,i)=(HstRn(j,i)*BinsYn(i)-(log(HstR(j,(i+1))*HstR(j,i))/2))/HstRn(j,i);	%dE=dA*Gamma/kT-dGaverage; Gamma0.5=(dE/kT)/(dA/kT)
				else
					HstRn(j,i)=0;
				end
			else
			end	%Calculating bins which are above treshold
		end	%Moving along current axis
	end	%Moving along pressure axis
	HstR=HstRn(:,(1:(end-1)));	%the last bin can't be calculated.
	
end	%Mode for Z axis values normalization

SndN(3);

function HstR=distrhst(Hst,BinsX,BinsXn,Dimn,InterpLevZ,InterpType)	%Redistributing histogram counts in X axis
%Outputs:
%HstR -	Rebinned histogram file

%Inputs:
%Hst - histogram data file
%BinsX -	Old bins vector for X axis
%BinsXn -	New X axes bins
%Dimn -	Dimension number for rebinning: X <1*>, or Y <2>.
if Dimn==1	%Rebinning X axis
    HstR=zeros(length(BinsXn)-1,size(Hst,2));
else	%Rebinning Y axis
    HstR=zeros(size(Hst,1),length(BinsXn)-1);
end

i=1:(length(BinsX)-1);
BinsXC=(BinsX(i)+BinsX(i+1))/2;	%Medium points vector of old bins
i=1:(length(BinsXn)-1);
BinsXnC=(BinsXn(i)+BinsXn(i+1))/2;	%Medium points vector of new bins
if ((InterpType==4)|(InterpType==5)|(InterpType==6)|(InterpType==7))&(length(BinsXn)/length(find(BinsX>BinsXn(1)&BinsX<BinsXn(end)))>=InterpLevZ)	%"Enforced linear" rebin mode and increased number of new bins
    %if ((InterpType==4)|(InterpType==5))&(length(BinsXn)/length(BinsX)>=InterpLevZ)	%"Enforced linear" rebin mode and increased number of new bins
    
    switch InterpType
    case {4	6}  %'Enfrcd Linr'});	Enforced Linear interpolation - for the case of increasing in bin numbers %'Enfrcd Linr Spln'});	Enforced Linear Spline interpolation - for the case of increasing in bin numbers
        HstL=Hst;
    case {5 7}	%'Enfrcd Expntl'});	Enforced Exponential interpolation - for the case of increasing in bin numbers 	%'Enfrcd Expntl Spln'});	Enforced Exponential Spline interpolation - for the case of increasing in bin numbers
        HstL=log10(loghst(Hst));
    end
    
    if Dimn==1	%Rebinning X axis
        for k=1:size(Hst,2)
            %	    HstR(:,k)=interp1(BinsXC,HstL(:,k),BinsXnC');	%new interpolated values
            switch InterpType
            case {4 5}	% no spline
                method='linear';
            case {6 7}  %spline
                method='spline';
            end
            HstR(:,k)=interp1AGB(BinsXC,HstL(:,k),BinsXnC',method);	%new interpolated values - no NaNs
            HstR((BinsXnC<BinsX(1))|(BinsXnC>BinsX(end)),k)=NaN;	%Outrange new bins
        end
    else	%Rebinning Y axis
        for k=1:size(Hst,1)
            %	    HstR(k,:)=interp1(BinsXC,HstL(k,:),BinsXnC);	%new interpolated values
            switch InterpType
            case {4 5}	% no spline
                method='linear';
            case {6 7}  %spline
                method='spline';
            end
            HstR(k,:)=interp1AGB(BinsXC,HstL(k,:),BinsXnC,method);	%new interpolated values - no NaNs
            HstR(k,(BinsXnC<BinsX(1))|(BinsXnC>BinsX(end)))=NaN;	%Outrange new bins
        end
    end
    
    switch InterpType
    case {4 6}	%'Enfrcd Linr'});	Enforced Linear interpolation - for the case of increasing in bin numbers
        HstR(isnan(HstR))=0;	%Replacing NaN values (new bins which are out of the old bins range) with zeros
    case {5	7} %'Enfrcd Expntl'});	Enforced Exponential interpolation - for the case of increasing in bin numbers
        HstR(isnan(HstR))=min(min(HstR));	%Replacing NaN values (new bins which are out of the old bins range) with zeros
        HstR=unloghst(10.^(HstR));
    end
    
    
else	%Usual rebin
    for i=1:(length(BinsX)-1)	%cicle through the old bins
        NMinXn=max(find(BinsXn<=BinsX(i))); %Maximal new bin boundary, lower than current old lower
        if length(NMinXn)==0;	%No new bin boundary, lower than current old low
            NMinXn=min(find(BinsXn<BinsX(i+1)));	%Closest new bin boundary, lower than current old higher
        end
        
        NMaxXn=min(find(BinsXn>=BinsX(i+1))); %Minimal new bin boundary, higher than current old higher
        if length(NMaxXn)==0;	%No new bin boundary, higher than current old high
            NMaxXn=max(find(BinsXn>BinsX(i)));	%Closest new bin boundary, higher than current old higher
        end
        
        if length(NMinXn)~=0&length(NMaxXn)~=0	%There some new bins intersecting with current old
            for k=NMinXn:(NMaxXn-1)
				prp=min(BinsXn(k+1),BinsX(i+1))-max(BinsXn(k),BinsX(i));   %Proportion of old bin which overlap current new bin, relative to the length of the whole old bin
				%prp=prp/(BinsXn(k+1)-BinsXn(k));
				prp=prp/(BinsX(i+1)-BinsX(i));
				if Dimn==1	%Rebinning X axis
					HstR(k,:)=HstR(k,:)+Hst(i,:)*prp;	%Adding proportional part of old counts from old bin to the new one
				else	%Rebinning Y axis
					HstR(:,k)=HstR(:,k)+Hst(:,i)*prp;	%Adding proportional part of old counts from old bin to the new one
				end
            end
        end
    end
    %HstRo=HstR;    %old array before interpolation
	if InterpType==1	%'None' interpolation
		MinimalAllowedAmount=min(HstR(:))-1;
	elseif InterpType==8	%'Zeroing' interpolation
		MinimalAllowedAmount=10^InterpLevZ;
	else
		%MinimalAllowedAmount=(sum(HstR(:))/(length(BinsXn)-1))*InterpLevZ;
		MinimalAllowedAmount=10^InterpLevZ;
	end
    
    %for k=2:(length(BinsXn)-2)  %cycle through new bins for interpolation
        if Dimn==1	%Rebinning X axis
            BinAmount=sum(HstR,2);	%Number of points in the bin
            BinsToRebin=find(BinAmount<MinimalAllowedAmount);   %too few points in the bin - interpolation needed
            BinsToStay=find(BinAmount>=MinimalAllowedAmount); 
            if ~isempty(BinsToRebin)
                %too few points in the bin - interpolation needed
                switch InterpType
                case 1  %None
                case 2  %linear
                    method='linear';
                    for k=1:size(HstR,2);   %cycle thgough the all Y bins
                        %HstR(BinsToRebin,k)=interp1AGB(BinsXC(BinsToStay),HstR(BinsToStay,k),BinsXnC(BinsToRebin)',method);	%new interpolated values - no NaNs
                        HstR(BinsToRebin,k)=interp1AGB(BinsXnC(BinsToStay),HstR(BinsToStay,k),BinsXnC(BinsToRebin)',method);	%new interpolated values - no NaNs
                    end   %cycle thgough the all Y bins
                case 3  %exponential
                    method='linear';
                    HstR=loghst(HstR);
                    for k=1:size(HstR,2);   %cycle thgough the all Y bins
                        %HstR(BinsToRebin,k)=interp1AGB(BinsXC(BinsToStay),HstR(BinsToStay,k),BinsXnC(BinsToRebin)',method);	%new interpolated values - no NaNs
                        HstR(BinsToRebin,k)=interp1AGB(BinsXnC(BinsToStay),HstR(BinsToStay,k),BinsXnC(BinsToRebin)',method);	%new interpolated values - no NaNs
                    end   %cycle thgough the all Y bins
                    HstR=unloghst(HstR);
				case 8 %Zeroing
                     HstR(BinsToRebin,:)=0;
               end
            end
        else	%Rebinning Y axis
            BinAmount=sum(HstR,1);	%Number of points in the bin
            BinsToRebin=find(BinAmount<MinimalAllowedAmount);   %too few points in the bin - interpolation needed
            BinsToStay=find(BinAmount>=MinimalAllowedAmount); 
            if ~isempty(BinsToRebin)
                %too few points in the bin - interpolation needed
                switch InterpType
                case 1  %None
                case 2  %linear
                    method='linear';
                    for k=1:size(HstR,1);   %cycle thgough the all X bins
                        %HstR(k,BinsToRebin)=interp1AGB(BinsXC(BinsToStay),HstR(k,BinsToStay),BinsXnC(BinsToRebin),method);	%new interpolated values - no NaNs
                        HstR(k,BinsToRebin)=interp1AGB(BinsXnC(BinsToStay),HstR(k,BinsToStay),BinsXnC(BinsToRebin),method);	%new interpolated values - no NaNs
                    end   %cycle thgough the all X bins
                case 3  %exponential
                    method='linear';
                    HstR=log(loghst(HstR));
                    for k=1:size(HstR,1);   %cycle thgough the all X bins
                        %HstR(k,BinsToRebin)=interp1AGB(BinsXC(BinsToStay),HstR(k,BinsToStay),BinsXnC(BinsToRebin),method);	%new interpolated values - no NaNs
                        HstR(k,BinsToRebin)=interp1AGB(BinsXnC(BinsToStay),HstR(k,BinsToStay),BinsXnC(BinsToRebin),method);	%new interpolated values - no NaNs
                    end   %cycle thgough the all X bins
                    HstR=unloghst(exp(HstR));
				case 8 %Zeroing
                    HstR(:,BinsToRebin)=0;
                end
            end
        end
        %end  %cycle through new bins for interpolation
end

HstR(isnan(HstR))=min(HstR(:));	%protection for NaN entries
