%thrdimhst -	Three dimensional histogram calculation
function [Hst,BinsX,BinsY,BinsZ]=thrdimhst(Readfile,XY,AutoX,MinX,MaxX,StepX,RebTypeX,...
    AutoY,MinY,MaxY,StepY,RebTypeY,AutoZ,MinZ,MaxZ,StepZ,RebTypeZ,FileType,...
    TimeRng,TimeRngType,TimeRngProf)
%Outputs:
%Hst -	Output historgam matrix.
%BinsX -	Calculated or provided X bins' boundaries vector.
%BinsY -	Calculated or provided Y bins' boundaries vector.

%Inputs:
%Readfile -	Flag for reading X and Y data from input vectors <1>, from single file <2*>.
%XY -	Vector of initial X and Y data (2xn), or filename for input data file for X and Y values, depending on "Readfile" value.
%AutoX -	Use absolute (full data range) Minimum and Maximum to range bins <1*>, or use user-defined values <0>.
%AutoY -	Use absolute (full data range) Minimum and Maximum to range bins <1*>, or use user-defined values <0>.
%RebTypeX -	Defines whether to use predefined steps number <1*>, bin width <2>, or user-defined bin boundaries vector <3>.
%RebTypeY -	Defines whether to use predefined steps number <1*>, bin width <2>, or user-defined bin boundaries vector <3>.
%MinX -	Minimal X range value.
%StepX -	X range steps number <1*>, X range bin width <2>, or
%user-defined bin boundaries vector <3> (depending on "StepsBinVect" value).
%MaxX -	Maximal X range value.
%MinY -	Minimal Y range value.
%StepY -	Y range steps number <1*>, X range bin width <2>, or
%user-defined bin boundaries vector <3> (depending on "StepsBinVect" value).
%MaxY -	Maximal Y range value.
%FileType -	Axon Text File (.ATF) <1*> with 2 channels, c	Axon Text File (.ATF) <2> with 1 channels, Text file (.TXT) <3>, or Axon binary file (.ABF) <4>.
%TimeRng -	Time change current range value, in pA, bins, dispersions, or in percents - acoording to Time range Type
%TimeRngType -	Time change current range type -  bins<1*>, dispersions <2>, percents <3>, pA <4>, 
%custom bins profile <5>
%TimeRngProf -	Time change current range pofile - uniform <1*>, 'Cstm' <2>,'Ln Up' <3>,...
%'Ln Dn' <4>,'Norm' <5>,'M' <6>
% 
% 


ReadStep=200000;	%Step for data reading from HDD

%===============Defining Minimum and Maximum to range bins

if Readfile==2	%------------reading X and Y data from single file
    DataFile=XY;	%Data filename
    fidDF=fopen(DataFile);	%Opens trace file
    
    %__________Reading file header
    switch FileType 
    case 1	%Axon Text File (.ATF) with 2 channels
        for i=1:10	%Reading text file header
            DataNotes{i}=fgetl(fidDF);
        end
    case 2	%Axon Text File (.ATF) with 1 channel
        for i=1:10	%Reading text file header
            DataNotes{i}=fgetl(fidDF);
        end
    case 3	%Text File (.txt)
    end
    
    %___________Define extremums
    if ((AutoX==1)|(AutoY==1)|(AutoZ==1))	%Use absolute (full data range) Minimum and Maximum to range bins
        switch FileType
        case 1	%Axon Text File (.ATF) with 2 channels
            [t]=sscanf(DataNotes{5},'%*6c %f %*1c %f');
            if (AutoX==1); MaxX=t(1); end
            if (AutoY==1); MaxY=t(2); end
            [t]=sscanf(DataNotes{6},'%*9c %f %*1c %f');
            if (AutoX==1); MinX=t(1); end
            if (AutoY==1); MinY=t(2); end
			if (AutoZ==1);
				XY=[0;0]; %Empty Data matrix
				t=0;	%Flag for the first step of extremum search
				Read=3*ReadStep;
				while Read>=3*ReadStep	%If the last time complete ReadStep length was read
					[XY,Read]=fscanf(fidDF,'%g %g %g',[3 ReadStep]);
					if Read~=0
						if t==0	%the first step of extremum search
							MinZ=XY(1,2)-XY(1,1);
							t=1;
						else
							MaxZ=XY(1,end)-MinZ;
						end
					end
				end
			end
			
		case 2	%Axon Text File (.ATF) with 1 channel
            if (AutoY==1);
                MaxY=sscanf(DataNotes{5},'%*6c %f');
                MinY=sscanf(DataNotes{6},'%*9c %f');
            end
            
            if AutoX==1
				if AutoZ==1
					XY=[0;0]; %Empty Data matrix
					t=0;	%Flag for the first step of extremum search
					Read=2*ReadStep;
					while Read>=2*ReadStep	%If the last time complete ReadStep length was read
						[XY,Read]=fscanf(fidDF,'%g %g',[2 ReadStep]);
						if Read~=0
							if t==0	%the first step of extremum search
								MinXY=min(XY,[],2);
								MaxXY=max(XY,[],2);
								MinZ=XY(1,2)-XY(1,1);
								t=1;
							else
								MinXY=min(MinXY,min(XY,[],2));
								MaxXY=max(MaxXY,max(XY,[],2));
								MaxZ=XY(1,end)-MinZ;
							end
						end
					end
					MinX=MinXY(1); MaxX=MaxXY(1); 
				else
					XY=[0;0]; %Empty Data matrix
					t=0;	%Flag for the first step of extremum search
					Read=2*ReadStep;
					while Read>=2*ReadStep	%If the last time complete ReadStep length was read
						[XY,Read]=fscanf(fidDF,'%g %g',[2 ReadStep]);
						if Read~=0
							if t==0	%the first step of extremum search
								MinXY=min(XY,[],2);
								MaxXY=max(XY,[],2);
								t=1;
							else
								MinXY=min(MinXY,min(XY,[],2));
								MaxXY=max(MaxXY,max(XY,[],2));
							end
						end
					end
					MinX=MinXY(1); MaxX=MaxXY(1); 
				end
            elseif AutoZ==1
                XY=[0;0]; %Empty Data matrix
				t=0;	%Flag for the first step of extremum search
				Read=3*ReadStep;
				while Read>=2*ReadStep	%If the last time complete ReadStep length was read
					[XY,Read]=fscanf(fidDF,'%g %g',[2 ReadStep]);
					if Read~=0
						
						if t==0	%the first step of extremum search
							MinZ=XY(1,2)-XY(1,1);
							t=1;
						else
							MaxZ=XY(1,end)-MinZ;
						end
					end
				end
				
			end
		case 3	%Text File (.txt)
			%             XY=[0;0]; %Empty Data matrix
			%             t=0;	%Flag for the first step of extremum search
%             Read=2*ReadStep;
%             while Read>=2*ReadStep	%If the last time complete ReadStep length was read
%                 [XY,Read]=fscanf(fidDF,'%g %g',[2 ReadStep]);
%                 if t==0	%the first step of extremum search
%                     MinXY=min(XY,[],2);
%                     MaxXY=max(XY,[],2);
%                     t=1;
%                 else
%                     MinXY=min(MinXY,min(XY,[],2));
%                     MaxXY=max(MaxXY,max(XY,[],2));
%                 end
%             end
%             if (AutoX==1); MinX=MinXY(1); MaxX=MaxXY(1); end
%             if (AutoY==1); MinY=MinXY(2); MaxY=MaxXY(2); end
        end
    end
    
    
else	%reading X and Y data from input vectors
    if ((AutoX==1)|(AutoY==1)|(AutoZ==1))	%Use absolute (full data range) Minimum and Maximum to range bins
        MinXY=min(XY,[],2);
        MaxXY=max(XY,[],2);
        if (AutoX==1); MinX=MinXY(1); MaxX=MaxXY(1); end
        if (AutoY==1); MinY=MinXY(2); MaxY=MaxXY(2); end
        if (AutoZ==1); MinZ=XY(3,2)-XY(3,1); MaxZ=MaxXY(3)-MinZ; end
    end
    
end



%***=================	Creating bins' boundaries vectors

switch RebTypeX	%Bins creation mode parameter
case 1	%predefined steps number
    BinsX=MinX:(MaxX-MinX)/StepX:MaxX;
case 2	%bin width 
    BinsX=MinX:StepX:(MaxX+StepX);
case 3	%user-defined bin boundaries vector
    BinsX=StepX;
end

switch RebTypeY	%Bins creation mode parameter
case 1	%predefined steps number
    BinsY=MinY:(MaxY-MinY)/StepY:MaxY;
case 2	%bin width 
    BinsY=MinY:StepY:(MaxY+StepY);
case 3	%user-defined bin boundaries vector
    BinsY=StepY;
end

switch RebTypeZ	%Bins creation mode parameter
case 1	%predefined steps number
    BinsZ=log(MinZ):log(MaxZ/MinZ)/StepZ:log(MaxZ);
    BinsZ=exp(BinsZ);
case 2	%bin width 
    BinsZ=MinZ:StepZ:(MaxZ+StepZ);
case 3	%user-defined bin boundaries vector
    BinsZ=StepZ;
end

Hst=zeros((length(BinsX)-1),(length(BinsY)-1),(length(BinsZ)-1));	%Initializing Histogram file

%*** Distributing data among bins

if Readfile==2	%reading X and Y data from single file
    status = fseek(fidDF,0,'bof');
    XY=[0;0]; %Empty Data matrix
    
	switch FileType
	case 1	%Axon Text File (.ATF) with 2 channels
		for i=1:10	%Reading text file header
			t=fgetl(fidDF);
		end
		Read=2*ReadStep;
		while Read>=2*ReadStep	%If the last time complete ReadStep length was read
			[XY,Read]=fscanf(fidDF,'%*g %g %g',[2 ReadStep]);
			if Read~=0
				Hst=distribute(XY,Hst,BinsX,BinsY);	%Filling histogram file
			end
		end
		
	case 2	%Axon Text File (.ATF) with 1 channel
		for i=1:10	%Reading text file header
			t=fgetl(fidDF);
		end
        Read=2*ReadStep;
        while Read>=2*ReadStep	%If the last time complete ReadStep length was read
			[XY,Read]=fscanf(fidDF,'%g %g',[2 ReadStep]);
			if Read~=0
				Hst=distribute(XY,Hst,BinsX,BinsY);	%Filling histogram file
			end
		end
		
	case 3	%Text File (.txt)
		Read=2*ReadStep;
		while Read>=2*ReadStep	%If the last time complete ReadStep length was read
			[XY,Read]=fscanf(fidDF,'%g %g',[2 ReadStep]);
			if Read~=0
				Hst=distribute(XY,Hst,BinsX,BinsY);	%Filling histogram file
			end
		end
		
    end
    
else	%reading X and Y data from input vectors
    Hst=distribute(XY,Hst,BinsX,BinsY);	%Filling histogram file
end


%*** Corrects non-uniform bins width

if RebTypeX==3	%Bins vector
    s=(BinsX(end)-BinsX(1))/(length(BinsX)-1);
    for i=1:(length(BinsX)-1)
        d=(BinsX(i+1)-BinsX(i))/s;
        Hst(i,:)=Hst(i,:)/d;
    end
end

if RebTypeY==3	%Bins vector
    s=(BinsY(end)-BinsY(1))/(length(BinsY)-1);
    for i=1:(length(BinsY)-1)
        d=(BinsY(i+1)-BinsY(i))/s;
        Hst(:,i)=Hst(:,i)/d;
    end
end


fclose(fidDF);	%Closes trace file

SndN(2);

function Hst=distribute(XY,Hst,BinsX,BinsY)
%distribute - this function distributes points from XY matrix into Hst matrix
%(adds new counts to values, xeisting in Hst), according to beans vectors
global EnblSnd
%Output:
%Hst -	Output historgam matrix.

%Inputs:
%XY - 	Data matrix.
%Hst -	Input historgam matrix.
%BinsX -	Calculated or provided X bins' boundaries vector.
%BinsY -	Calculated or provided Y bins' boundaries vector.


SizeX=size(Hst,1); SizeY=size(Hst,2);	%Sizes of hystogram file in X and Y directions

PointX=fix(SizeX/2); PointY=fix(SizeY/2);	%Initial positions of latest bin coordinates
SizeD=size(XY,2);	%Length of XY data matrix
for i=1:SizeD	%Cycle through XY data matrix
    
    %** X binning
    if XY(1,i)<=BinsX(PointX+1)	%Moving down through the bins
        while PointX>0	%we are above the lowest bin boundary
            if XY(1,i)>BinsX(PointX)	%fit in the current bin
                break
            else
                PointX=PointX-1;	%1 step down
            end
        end
    else	%Moving up through the bins
%         PointX=PointX+1;	%1 step up
        while PointX<(SizeX+1)	%we are below the topmost bin boundary
            if XY(1,i)<=BinsX(PointX+1)	%fit in the current bin
                break
            else
                PointX=PointX+1;	%1 step up
            end
        end
        PointX=max(1,min((SizeX+1),PointX));	%Limiting the maximum value
    end
    
    %** Y binning
    if XY(2,i)<=BinsY(PointY)	%Moving down through the bins
        while PointY>0	%we are above the lowest bin boundary
            if XY(2,i)>BinsY(PointY-1)	%fit in the current bin
                break
            else
                PointY=PointY-1;	%1 step down
            end
        end
    else	%Moving up through the bins
%         PointY=PointY+1;	%1 step up
        while PointY<(SizeY+1)	%we are below the topmost bin boundary
            if XY(2,i)<=BinsY(PointY)	%fit in the current bin
                break
            else
                PointY=PointY+1;	%1 step up
            end
        end
        PointY=max(1,min((SizeY+1),PointY));	%Limiting the maximum value
    end
    
    %** Adding 1 count to histogram bin
    if (PointX>0)&(PointY>0)&(PointX<=SizeX)&(PointY<=SizeY)	%Point coordinates are within hisogram matrix range
        Hst(PointX,PointY)=Hst(PointX,PointY)+1; 
    end
end

SndN(1);
