%tracehst - function for creation 1D histogram from the part of 2D histogram
function [HstT, BinsT]=tracehst(Hst,BinsX,MinX,MaxX,AutoX,BinsY,MinY,MaxY,AutoY,Dimn,NormZ)

%Outputs:
%HstT	-	traced 1D histogram vector
%BinsT -	bins vector for 1D histogam

%Inputs:
%Hst -	2D histogram data matrix
%BinsX -	bins for X axis
%MinX -	minimal X axis value for the trace range
%MaxX -	maximal X axis value for the trace range
%AutoX -	Autoselect minimal and maximal values from the full axis range
%BinsY -	bins for Y axis
%MinY -	minimal Y axis value for the trace range
%MaxY -	maximal Y axis value for the trace range
%AutoY -	Autoselect minimal and maximal values from the full axis range
%Dimn -	dimension to go along (other dimension will be summarized) <1> or<2>
%NormZ -	flag for normalizing values in histogram relative to the total amount of points - <1*> or <0>

if AutoX==1	%Autoselect minimal and maximal values from the full axis range
	NMinX=1;NMaxX=length(BinsX);
else
	Nmbs=find((BinsX>=MinX)&(BinsX<=MaxX));	%Bins boundaries fitting in the range
	NMinX=min(Nmbs);
	NMaxX=max(Nmbs);
end

if AutoY==1	%Autoselect minimal and maximal values from the full axis range
	NMinY=1;NMaxY=length(BinsY);
else
	Nmbs=find((BinsY>=MinY)&(BinsY<=MaxY));	%Bins boundaries fitting in the range
	NMinY=min(Nmbs);
	NMaxY=max(Nmbs);
end

HstT=[]; Hst(isnan(Hst))=min(Hst(:));	%protection for NaN entries
if Dimn==1	%Moving along X (current)axis and summarizing through the selected Y (pressure) region
	BinsT=BinsX(NMinX:NMaxX);
	for i=NMinX:(NMaxX-1)
		switch NormZ    %Mode of trace normalizing
			case {1,2,3,9} 
				%case 1 'Z Absolute'
				%case 2  %'Z/(Trc pnts)' normalizing values in histogram relative to the total amount of points in trace histogram
				%case 3   %'Z/(Trc max)' normalizing values in histogram relative to the maximum amount of points in trace histogram
				%case 9   %'Z/(All pnts)'
				HstT(end+1)=sum(Hst(i,NMinY:(NMaxY-1)));
			case {4,5,6,17}    
				%case 4  %'Z*Val'
				%case 5  %'Z*Val/(Trc pnts)'
				%case 6  %'Z*Val/(Trc max)'
				%case 17   %'Z/(Val max)' normalizing values in histogram relative to the maximal possible Value (bin boundary with the highest absolute value - MaxX (MaxY) or MinX(MinY)
				j=NMinY:(NMaxY-1);
				HstT(end+1)=sum(Hst(i,j).*(BinsY(j)+BinsY(j+1))/2);	%Multiplying value probability on it's magnitude
			case 7  %'Z*Val/(Drn pnts)'
				j=NMinY:(NMaxY-1);
				if sum(Hst(i,:))==0
					HstT(end+1)=0;
				else
					HstT(end+1)=sum(Hst(i,j).*(BinsY(j)+BinsY(j+1))/2)/sum(Hst(i,:));	%Multiplying value probability on it's magnitude and dividing on all points number in this bin
				end
			case 8   %'Z/(Drn pnts)'
				j=NMinY:(NMaxY-1);
				if sum(Hst(i,:)) ~= 0
					HstT(end+1)=sum(Hst(i,j))/sum(Hst(i,:));	%Dividing on all points number in this bin
				else
					HstT(end+1)=0;
				end
			case 10  %'Z*Val/(Drn rng pnts)'
				j=NMinY:(NMaxY-1);
				if sum(Hst(i,j))==0
					HstT(end+1)=0;
				else
					HstT(end+1)=sum(Hst(i,j).*(BinsY(j)+BinsY(j+1))/2)/sum(Hst(i,j));	%Multiplying value probability on it's magnitude and dividing on all points number in this bin
				end
			case 11	%'Z Mean'	Average calculated among the selected bins
				HstT(end+1)=mean(Hst(i,NMinY:(NMaxY-1)));
			case 12	%'Z Std'	Standard deviation among selected bins
				HstT(end+1)=std(Hst(i,NMinY:(NMaxY-1)));
			case 13	%'Z Mean <>0'	Average calculated among the selected bins, if they are <> 0
				t=Hst(i,NMinY:(NMaxY-1)); t=t(t~=0);
				if length(t)>0
					HstT(end+1)=mean(t);
				else
					HstT(end+1)=0;
				end
			case 14	%'Z Std <>0'	Standard deviation among selected bins, if they are <> 0
				t=Hst(i,NMinY:(NMaxY-1)); t=t(t~=0);
				if length(t)>0
					HstT(end+1)=std(t);
				else
					HstT(end+1)=0;
				end
			case 15	%'Z Geom Mean >0'	Average calculated among the selected bins, if they are <> 0
				t=Hst(i,NMinY:(NMaxY-1)); t=t(t>0);
				if length(t)>0
					HstT(end+1)=exp(mean(log(t)));
				else
					HstT(end+1)=0;
				end
			case 16	%'Z Geom Std >0'	Standard deviation among selected bins, if they are <> 0
				t=Hst(i,NMinY:(NMaxY-1)); t=t(t>0);
				if length(t)>0
					HstT(end+1)=exp(std(log(t)));
				else
					HstT(end+1)=0;
				end
		end    %Mode of trace normalizing
	end
else %Moving along Y (pressure) axis and summarizing through the selected region X (current)
	BinsT=BinsY(NMinY:NMaxY);
	for i=NMinY:(NMaxY-1)
		switch NormZ    %Mode of trace normalizing
			case {1,2,3,9} 
				%case 1 'Z Absolute'
				%case 2  %'Z/(Trc pnts)' normalizing values in histogram relative to the total amount of points in trace histogram
				%case 3   %'Z/(Trc max)' normalizing values in histogram relative to the maximum amount of points in trace histogram
				%case 9   %'Z/(All pnts)'
				HstT(end+1)=sum(Hst(NMinX:(NMaxX-1),i));
			case {4,5,6,17}    
				%case 4  %'Z*Val'
				%case 5  %'Z*Val/(Trc pnts)'
				%case 6  %'Z*Val/(Trc max)'
				%case 17   %'Z/(Val max)' normalizing values in histogram relative to the maximal possible Value (bin boundary with the highest absolute value - MaxX (MaxY) or MinX(MinY)
				j=NMinX:(NMaxX-1);
				HstT(end+1)=sum(Hst(j,i)'.*(BinsX(j)+BinsX(j+1))/2);	%Multiplying value probability on it's magnitude
			case 7  %'Z*Val/(Drn pnts)'
				j=NMinX:(NMaxX-1);
				if sum(Hst(:,i)) ~= 0
					HstT(end+1)=sum(Hst(j,i)'.*(BinsX(j)+BinsX(j+1))/2)/sum(Hst(:,i));	%Multiplying value probability on it's magnitude and dividing on all points number in this bin
				else
					HstT(end+1)=0;
				end
			case 8   %'Z/(Drn pnts)'
				j=NMinX:(NMaxX-1);
				HstT(end+1)=sum(Hst(j,i))/sum(Hst(:,i));	%Dividing on all points number in this bin
			case 10  %'Z*Val/(Drn pnts)'
				j=NMinX:(NMaxX-1);
				if sum(Hst(j,i)) ~= 0
					HstT(end+1)=sum(Hst(j,i)'.*(BinsX(j)+BinsX(j+1))/2)/sum(Hst(j,i));	%Multiplying value probability on it's magnitude and dividing on all points number in this bin
				else
					HstT(end+1)=0;
				end
			case 11	%'Z Mean'	Average calculated among the selected bins
				HstT(end+1)=mean(Hst(NMinX:(NMaxX-1),i));
			case 12	%'Z Std'	Standard deviation among selected bins
				HstT(end+1)=std(Hst(NMinX:(NMaxX-1),i));
			case 13	%'Z Mean <>0'	Average calculated among the selected bins, if they are <> 0
				t=Hst(NMinX:(NMaxX-1),i); t=t(t~=0);
				if length(t)>0
					HstT(end+1)=mean(t);
				else
					HstT(end+1)=0;
				end
			case 14	%'Z Std <>0'	Standard deviation among selected bins, if they are <> 0
				t=Hst(NMinX:(NMaxX-1),i); t=t(t~=0);
				if length(t)>0
					HstT(end+1)=std(t);
				else
					HstT(end+1)=0;
				end
			case 15	%'Z Geom Mean >0'	Average calculated among the selected bins, if they are <> 0
				t=Hst(NMinX:(NMaxX-1),i); t=t(t>0);
				if length(t)>0
					HstT(end+1)=exp(mean(log(t)));
				else
					HstT(end+1)=0;
				end
			case 16	%'Z Geom Std >0'	Standard deviation among selected bins, if they are <> 0
				t=Hst(NMinX:(NMaxX-1),i); t=t(t>0);
				if length(t)>0
					HstT(end+1)=exp(std(log(t)));
				else
					HstT(end+1)=0;
				end
		end    %Mode of trace normalizing
	end
end
%size(HstT)%!
%sum(HstT)%!

%s=(BinsT(end)-BinsT(1))/(length(BinsT)-1);
%for i=1:(length(BinsT)-1)
%   d=(BinsT(i+1)-BinsT(i))/s;
%   HstT(i)=HstT(i)/d;
%end

switch NormZ    %Mode of trace normalizing
	case {1,4,7,8}
		%case 1  %'Z Absolute'
		%case 4  %'Z*Val'
		%case 7  %'Z*Val/(Drn pnts)'
		%case 8   %'Z/(Drn pnts)'
	case {2,5}
		%case 2  %'Z/(Trc pnts)' normalizing values in histogram relative to the total amount of points in trace histogram
		%case 5  %'Z*Val/(Trc pnts)'
		HstT=HstT/sum(HstT);
	case {3,6}   
		%case 3   %'Z/(Trc max)' normalizing values in histogram relative to the maximum amount of points in trace histogram
		%case 6  %'Z*Val/(Trc max)'
		%HstT=HstT/max(HstT);
		HstT=HstT/max(HstT(abs(HstT)==max(abs(HstT)))); % Contents of the bin with maximal absolut value. If bos positive and negative bins have the maximal absolute value, positive one is chosen
	case 9   %'Z/(All pnts)'
		HstT=HstT/sum(sum(Hst));
	case 17 %	'Z/(Val max)' normalizing values in histogram relative to the maximal possible Value (bin boundary with the highest absolute value - MaxX (MaxY) or MinX(MinY)
		if Dimn==1	%Moving along X (current)axis and summarizing through the selected Y (pressure) region
			MaxVal=max(BinsY(abs(BinsY)==max(abs(BinsY))));
		else 	%Moving along Y (pressure)axis and summarizing through the selected X (current) region
			MaxVal=max(BinsX(abs(BinsX)==max(abs(BinsX))));
		end
		HstT=HstT/MaxVal; % Contents of the bin with maximal absolut value. If bos positive and negative bins have the maximal absolute value, positive one is chosen
end
